#<profile4xi profile = "12" />
# =================================================================================================
#<program4xi program = "npu2device4xi.py">
#<abstract4xi abstract = "NPU management"/>
#<refer4xi reference = "device4xi.py"/>
#<verify4xi verification = "10" target = "npu2event4xi.py">
#<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; ACK4systemtesting; [Rel 7.21]"/>
# =================================================================================================

# -------------------------------------------------------------------------------------------------
# Public API
# -------------------------------------------------------------------------------------------------
#<interface4xi interface = " 
__all__ = [ 'NPU4Xi',
            'init2npu4xi',
            'get2npu4xi',
            'set2npu4xi']
#"
#/>


# -------------------------------------------------------------------------------------------------
# Standard Imports                          
# -------------------------------------------------------------------------------------------------
#<standardize4xi standard = "
import os
from platform import processor
import sys
import threading                
import _thread   

from decimal import *
#"
#/>


# -------------------------------------------------------------------------------------------------
# Scope4Xi imports                               
# -------------------------------------------------------------------------------------------------
#<dragonize4xi dragonization = "
import version4xi
from version4xi import VersionKB4Xi
from platformids4xi  import get2platformids4xi
#"
#/>

# -------------------------------------------------------------------------------------------------
# Multiprocessing Imports                          
# -------------------------------------------------------------------------------------------------
#<process4xi process = "
import _multiprocessing
#"
#/>


# -------------------------------------------------------------------------------------------------
# DragonXi imports                              
# -------------------------------------------------------------------------------------------------
#<dragonize4xi dragonization = "
from ace_object4xi import ace_object4xi
from cpu_corecount4xi import cpu_corecount4xi
from print4xi import print4xi
from time4xi import time4xi
from reason_object4xi import reason_object4xi
from sense_object4xi import sense_object4xi
#"
#/>

# -------------------------------------------------------------------------------------------------
# Global constants                             
# ------------------------------------------------------------------------------------------------
#<globalize4xi globalization = "
global npu2device4xi                                                    # Device of NPU

global npu2trace4xi                                                     # TRACE

global fetch2code4npu                                                   # Fetched code

global import2use4npu                                                   # Imports of target function for Process4Xi

global kb2fetch4npu                                                     # Knowledgebase for fetching
global kb2kernel4npu                                                    # Knowledgebase for kernel   

global folder2lib4npu                                                   # Folder of NPU library

global profile2fetch                                                       # Profile knowledgebase for fetching
global keys2profile4npu

global target2function4npu                                              # Target function for Process4Xi
      
#"
#/>

# -------------------------------------------------------------------------------------------------
# Settings
# -------------------------------------------------------------------------------------------------
#<set4xi setting = "

#"
#"/>


# -------------------------------------------------------------------------------------------------
#<function4xi function = "init2npu4xi" usage = "
#
#   # example 1:
#   try:
#       npu2xi = init2npu4xi()                                                                              # no parameters - the system should initialize all   
#       print('(Step 2B/33) OF NPU4XI5TEST - INITIALIZED NPU4XI TO: ', npu2xi)                           # {'NACK2RETURN': ' ', 'ACK2RETURN': ' 1C1D1E1F2A3A4A', 
#                                                                                                                 # 'TYPE': 'CL_DEVICE_TYPE_NPU', 'ID': 'NPU', 'MAX2UNITS4COMPUTE': 4}
#   except:
#       print('(Step 2Z/33) OF NPU4XI5TEST *** FAILED TO INITIALIZE NPU4XI', time4xi()) 
#
#   # example 2:
#   try:
#       # ---------------------------------------------------------------------------------------------
#       # CREATE OBJECT                        
#       # ---------------------------------------------------------------------------------------------        
#       cc2xi = NPU4Xi()
#       print('(Step 5B/33) OF NPU4XI5TEST - CREATED NPU4XI OBJECT: ', cc2xi)                               # <npu2device4xi.NPU4Xi object at 0x000000000331B630> 
#   except:
#       print('(Step 5Z/33) OF NPU4XI5TEST *** FAILED TO CREATE NPU4XI OBJECT')
#   
#   # ---------------------------------------------------------------------------------------------
#   # GET METHOD                        
#   # ---------------------------------------------------------------------------------------------          
#   print('(Step 6A/33) OF NPU4XI5TEST - TRYING TO GET DEVICE')
#   try:                               
#       cpu6xi = cc2xi.get2npu()                                  
#       print('(Step 6B/33) OF NPU4XI5TEST - GOT NPU: ', cpu6xi)                                            # {'NACK2RETURN': ' ', 'ACK2RETURN': ' 1C1D1E1F2A3A4A', 
#                                                                                                                 # 'TYPE': 'CL_DEVICE_TYPE_NPU', 'ID': 'NPU', 'MAX2UNITS4COMPUTE': 4} 
#   except:
#       print('(Step 6Z/33) OF NPU4XI5TEST *** FAILED TO GET NPU')   
#">

# -------------------------------------------------------------------------------------------------   
def init2npu4xi(task4init2npu=None):

    '''
    initializes npu2device4xi
    '''
    
    global npu2device4xi  
    
    # -----------------------------------------------------------------------------------------
    # (Step 1/70) PARAMETERS           
    # -----------------------------------------------------------------------------------------          
    class2print = "init2npu4xi" 
    method2print = "init2npu4xi"

    message2print = "{(Step 1A/70) started" + "; init2npu4xi-started: " + str(init2npu4xi)  + "; time: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)                                                              # <function init2npu4xi at 0x000000000327C148>
  
             
    message2print = "{(Step 1B/70) passed" + "; task4init2npu-to-init2npu4xi: " + str(task4init2npu) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)                                                              # None

    code2ack  = ' '
    code2nack = ' '    
    
    npu2device4xi = {}                                                                                           # initializes to empty dictionary
    corecount2xi = 1                                                                                                # default core count
    try:
        corecount2xi = cpu_corecount4xi()
        message2print = "{(Step 1C/70) got" + "; corecount2xi-got-by-init2npu4xi: " + str(corecount2xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                                                          # 4
        code2ack  = code2ack + '1C-'                                                         
    except:
        message2print = "{(Step 1Z1/70) yielded" + "; corecount2xi-yielded-by-init2npu4xi: " + str(corecount2xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '1Z1-' 
               
    try:             
        if task4init2npu is None:
            # -----------------------------------------------------------------------------------------
            # NO PARAMETERS GIVEN BY CALLER FOR INITIALIZATION
            # -----------------------------------------------------------------------------------------    
            task4init2npu = {}                                                                                   # 
            task4init2npu['ID'] = 4033                                                                           # DEFAULT ID for NPU 
            code2ack  = code2ack + '1D-'
            task4init2npu['TYPE'] = 'CL_DEVICE_TYPE_NPU'                                                      #  
            code2ack  = code2ack + '1E-'
            task4init2npu['MAX2UNITS4COMPUTE'] = corecount2xi                                                    # GET THE NUMBER OF NPU CORES AVAILABLE                                                                      # 
            code2ack  = code2ack + '1F-'
            task4init2npu['NAME'] = processor()                                                                  # Processor from OS

            task4init2npu['MAX2DIMENSIONS4WORKITEMS'] = 			                       3
            task4init2npu['MAX2WORKITEM0'] = 				                            1024
            task4init2npu['MAX2WORKITEM1'] = 				                            1024
            task4init2npu['MAX2WORKITEM2'] = 				                            1024
            task4init2npu['MAX2SIZE4WORKGROUP'] = 				                        1024
            task4init2npu['PREFERRED2WIDTHCHAR4VECTOR'] = 			                      16
            task4init2npu['PREFERRED2WIDTHSHORT4VECTOR'] = 			                       8
            task4init2npu['PREFERRED2WIDTHINT4VECTOR'] = 			                       4
            task4init2npu['PREFERRED2WIDTHLONG4VECTOR'] = 			                       2
            task4init2npu['PREFERRED2WIDTHFLOAT4VECTOR'] = 			                       4
            task4init2npu['PREFERRED2WIDTHDOUBLE4VECTOR'] = 		                       0
            task4init2npu['NATIVE2WIDTHCHAR4VECTOR'] = 			                          16
            task4init2npu['NATIVE2WIDTHSHORT4VECTOR'] = 			                       8
            task4init2npu['NATIVE2WIDTHINT4VECTOR'] = 			                           4
            task4init2npu['NATIVE2WIDTHLONG4VECTOR'] = 			                           2
            task4init2npu['NATIVE2WIDTHFLOAT4VECTOR'] = 			                       4
            task4init2npu['NATIVE2WIDTHDOUBLE4VECTOR'] = 			                       0
            task4init2npu['MAX2FREQUENCY4CLOCK'] = 				                        3210                    # MHz
            task4init2npu['BITS2ADDRESS'] = 					                          64
            task4init2npu['MAX2ALLOCATION4MEMORY'] = 			                  1073741824
            task4init2npu['SUPPORT2IMAGE'] = 				                          'NACK'
            task4init2npu['MAX2SIZE4KERNELARGUMENT'] = 			                        4096
            task4init2npu['ALIGNMENT2ADDRESS4BASE'] = 		                            1024
            task4init2npu['MINIMUM2ALIGNMENT4DATATYPE'] = 	                             128 
            task4init2npu['DENORMS2SINGLEPRECISION4FLOATINGPOINTCAPABILITY'] = 		   'ACK'
            task4init2npu['QUIET2NANS'] = 					                           'ACK'
            task4init2npu['ROUND2NEAREST4EVEN'] = 			                           'ACK'
            task4init2npu['ROUND2ZERO'] = 				                               'ACK'
            task4init2npu['ROUND2+VE3INFINITY'] = 			                           'ACK'
            task4init2npu['IEEE754-2008FUSED2MULTIPLY-ADD'] = 		                  'NACK'
            task4init2npu['TYPE4CACHE'] = 					                    'Read/Write'
            task4init2npu['SIZE2LINE4CACHE'] = 				                              64
            
            task4init2npu['SIZE2CACHE'] = 					                           65536
            task4init2npu['SIZE2MEMORY4GLOBAL'] = 				                  3221225472
            task4init2npu['SIZE2BUFFER4CONSTANT'] = 				                   65536
            task4init2npu['MAX2NUMBER4CONSTANTARGS'] = 			                           8
            
            task4init2npu['TYPE2MEMORY4LOCAL'] = 				                     'Global'
            task4init2npu['SIZE2MEMORY4LOCAL'] = 				                       32768
            task4init2npu['SIZE2PREFERREDWORKGROUPMULTIPLE4KERNEL'] = 	                   1
            
            
            task4init2npu['SUPPORT2CORRECTION4ERROR'] = 			                       0
            task4init2npu['MEMORY2UNIFIED4HOSTANDDEVICE'] = 		                       1
            task4init2npu['RESOLUTION2TIMER4PROFILING'] = 			                     318
            task4init2npu['ENDIANESS2DEVICE'] = 				                    'Little'
            task4init2npu['AVAILABLE'] = 					                           'ACK'
            task4init2npu['AVAILABLE2COMPILER'] = 				                       'ACK'
            			 
            task4init2npu['EXECUTE2KERNELS4OPENCL'] = 			                       'ACK'
            task4init2npu['EXECUTE2FUNCTION4NATIVE'] = 			                       'ACK'
            				 
            task4init2npu['OUT-OF-ORDER2QUEUE'] = 				                      'NACK'
            task4init2npu['PROFILING2QUEUE'] = 					                       'ACK'
            task4init2npu['ID2PLATFORM'] = 					              '0000000001509568'
            
            task4init2npu['VENDOR'] = 					                      'AuthenticAMD'
            task4init2npu['VERSION2DRIVER'] = 				                           '2.0'
            task4init2npu['PROFILE'] = 					                      'FULL_PROFILE'
            task4init2npu['VERSION'] = 					  'OpenCL 1.1 ATI-Stream-v2.3 (451)'
            task4init2npu['EXTENSIONS'] = 				  'cl_amd_fp64 cl_khr_global_int32_base_atomics cl_khr_global_int32_extended_atomics cl_khr_local_int32_base_atomics cl_khr_local_int32_extended_atomics cl_khr_int64_base_atomics cl_khr_int64_extended_atomics cl_khr_byte_addressable_store cl_khr_gl_sharing cl_ext_device_fission cl_amd_device_attribute_query cl_amd_media_ops cl_amd_popcnt cl_amd_printf cl_khr_d3d10_sharing' 

            message2print = "{(Step 1DA/70) initialized" + "; task4init2npu-initialized-by-init2npu4xi to: " + str(task4init2npu)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '1D-'
            # {'RESOLUTION2TIMER4PROFILING': 318, 'ID2PLATFORM': '0000000001509568', 'PROFILING2QUEUE': 'ACK', 'EXECUTE2KERNELS4OPENCL': 'ACK', 
            #  'NATIVE2WIDTHLONG4VECTOR': 2, 'MAX2UNITS4COMPUTE': 4, 'SIZE2MEMORY4GLOBAL': 3221225472, 'NATIVE2WIDTHFLOAT4VECTOR': 4, 
            #  'MAX2SIZE4WORKGROUP': 1024, 'PREFERRED2WIDTHCHAR4VECTOR': 16, 'SIZE2CACHE': 65536, 'IEEE754-2008FUSED2MULTIPLY-ADD': 'NACK', 
            #  'TYPE4CACHE': 'Read/Write', 'PREFERRED2WIDTHINT4VECTOR': 4, 'SIZE2PREFERREDWORKGROUPMULTIPLE4KERNEL': 1, 'NATIVE2WIDTHINT4VECTOR': 4, 
            #  'SIZE2BUFFER4CONSTANT': 65536, 'EXECUTE2FUNCTION4NATIVE': 'ACK', 'PREFERRED2WIDTHDOUBLE4VECTOR': 0, 'MAX2NUMBER4CONSTANTARGS': 8, 
            #  'VERSION2DRIVER': '2.0',
            #  'EXTENSIONS': 'cl_amd_fp64 cl_khr_global_int32_base_atomics cl_khr_global_int32_extended_atomics cl_khr_local_int32_base_atomics cl_khr_local_int32_extended_atomics cl_khr_int64_base_atomics cl_khr_int64_extended_atomics cl_khr_byte_addressable_store cl_khr_gl_sharing cl_ext_device_fission cl_amd_device_attribute_query cl_amd_media_ops cl_amd_popcnt cl_amd_printf cl_khr_d3d10_sharing',
            #  'AVAILABLE2COMPILER': 'ACK', 'MAX2DIMENSIONS4WORKITEMS': 3, 'SUPPORT2CORRECTION4ERROR': 0, 'BITS2ADDRESS': 64, 'AVAILABLE': 'ACK',
            #  'SIZE2MEMORY4LOCAL': 32768, 'VENDOR': 'AuthenticAMD', 
            #  'SUPPORT2IMAGE': 'NACK', 'MAX2SIZE4KERNELARGUMENT': 4096, 'OUT-OF-ORDER2QUEUE': 'NACK', 'ALIGNMENT2ADDRESS4BASE': 1024,
            #  'PROFILE': 'FULL_PROFILE', 'TYPE2MEMORY4LOCAL': 'Global', 'PREFERRED2WIDTHFLOAT4VECTOR': 4, 'PREFERRED2WIDTHLONG4VECTOR': 2,
            #  'MAX2FREQUENCY4CLOCK': 3210, 'PREFERRED2WIDTHSHORT4VECTOR': 8, 'ID': 4033, 'MAX2WORKITEM2': 1024,
            #  'NATIVE2WIDTHDOUBLE4VECTOR': 0, 'ROUND2ZERO': 'ACK', 'NAME': 'AMD64 Family 16 Model 4 Stepping 2, AuthenticAMD',
            #  'MAX2WORKITEM1': 1024, 'MAX2WORKITEM0': 1024, 'SIZE2LINE4CACHE': 64, 'MAX2ALLOCATION4MEMORY': 1073741824,
            #  'NATIVE2WIDTHCHAR4VECTOR': 16, 'QUIET2NANS': 'ACK', 'NATIVE2WIDTHSHORT4VECTOR': 8, 'ROUND2NEAREST4EVEN': 'ACK',
            #  'VERSION': 'OpenCL 1.1 ATI-Stream-v2.3 (451)', 'MEMORY2UNIFIED4HOSTANDDEVICE': 1, 'ENDIANESS2DEVICE': 'Little',
            #  'MINIMUM2ALIGNMENT4DATATYPE': 128, 'ROUND2+VE3INFINITY': 'ACK',
            #  'TYPE': 'CL_DEVICE_TYPE_NPU', 'DENORMS2SINGLEPRECISION4FLOATINGPOINTCAPABILITY': 'ACK'}; time: 04:59:01 05/03/11 Pacific Daylight Time}
 
        else:
            pass                        
    except: 
        message2print = "{(Step 1Z1/70) yielded" + "; task4init2npu-yielded-by-init2npu4xi: " + str(task4init2npu) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '1Z2-' 


     

    # ---------------------------------------------------------------------------------------------
    # TASK EITHER GENERATED BY THIS PROGRAM (NONE GIVEN) OR GIVEN BY USER    
    # ---------------------------------------------------------------------------------------------
    keys2task = task4init2npu.keys()        
    message2print = "{(Step 8/70) using" + "; keys2task-using-by-init2npu4xi: " + str(sorted(keys2task))  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)    
    # 

    if 'ID' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 2/70) - ID
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['ID'] = task4init2npu['ID']
            
            message2print = "{(Step 2A/70) initialized" + "; id-initialized-by-init2npu4xi to: " + str(npu2device4xi['ID'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '2A-'
        except: 
            message2print = "{(Step 2Z1/70) yielded" + "; id-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '2Z1-' 

    if 'TYPE' in keys2task:        
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 3/70) - TYPE
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['TYPE'] = task4init2npu['TYPE']
            
            message2print = "{(Step 3A/70) initialized" + "; type-initialized-by-init2npu4xi to: " + str(npu2device4xi['TYPE'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '3A-'
        except: 
            message2print = "{(Step 3Z1/70) yielded" + "; type-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '3Z1-'             
    

    if 'MAX2UNITS4COMPUTE' in keys2task:        
        try:
            # -----------------------------------------------------------------------------------------    
            # (Step 4/70) - MAX COMPUTE UNITS
            # -----------------------------------------------------------------------------------------             
            if task4init2npu['MAX2UNITS4COMPUTE'] > corecount2xi:
                npu2device4xi['MAX2UNITS4COMPUTE'] = corecount2xi
            if task4init2npu['MAX2UNITS4COMPUTE'] <= 0:
                npu2device4xi['MAX2UNITS4COMPUTE'] = corecount2xi    
            
            npu2device4xi['MAX2UNITS4COMPUTE'] = task4init2npu['MAX2UNITS4COMPUTE']
            
            message2print = "{(Step 4A/70) initialized" + "; max2units4compute-initialized-by-init2npu4xi to: " + str(npu2device4xi['MAX2UNITS4COMPUTE'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '4A-'
        except:
            message2print = "{(Step 4Z1/70) yielded" + "; max2units4compute-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '4Z1-'     
        

    if 'NAME' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 5/70) - NAME
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['NAME'] = task4init2npu['NAME']
            
            message2print = "{(Step 5A/70) initialized" + "; name-initialized-by-init2npu4xi to: " + str(npu2device4xi['NAME'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '5A-'
        except: 
            message2print = "{(Step 5Z1/70) yielded" + "; name-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '5Z1-' 

    if 'MAX2DIMENSIONS4WORKITEMS' in keys2task:
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 6/70) - MAX2DIMENSIONS4WORKITEMS
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['MAX2DIMENSIONS4WORKITEMS'] = task4init2npu['MAX2DIMENSIONS4WORKITEMS']
            
            message2print = "{(Step 6A/70) initialized" + "; max2dimensions4workitems-initialized-by-init2npu4xi to: " + str(npu2device4xi['MAX2DIMENSIONS4WORKITEMS'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '6A-'
        except: 
            message2print = "{(Step 6Z1/70) yielded" + "; max2dimensions4workitems-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '6Z1-' 
    
    

    if 'MAX2WORKITEM0' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 7/70) - MAX2WORKITEM0
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['MAX2WORKITEM0'] = task4init2npu['MAX2WORKITEM0']
            
            message2print = "{(Step 7A/70) initialized" + "; max2workitem0-initialized-by-init2npu4xi to: " + str(npu2device4xi['MAX2WORKITEM0'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '7A-'
        except: 
            message2print = "{(Step 7Z1/70) yielded" + "; max2workitem0-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '7Z1-' 
    
    

    if 'MAX2WORKITEM1' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 8/70) - MAX2WORKITEM1
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['MAX2WORKITEM1'] = task4init2npu['MAX2WORKITEM1']
            
            message2print = "{(Step 8A/70) initialized" + "; max2workitem1-initialized-by-init2npu4xi to: " + str(npu2device4xi['MAX2WORKITEM1'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '8A-'
        except: 
            message2print = "{(Step 8Z1/70) yielded" + "; max2workitem1-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '8Z1-' 
    
    

    if 'MAX2WORKITEM2' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 9/70) - MAX2WORKITEM2
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['MAX2WORKITEM2'] = task4init2npu['MAX2WORKITEM2']
            
            message2print = "{(Step 9A/70) initialized" + "; max2workitem2-initialized-by-init2npu4xi to: " + str(npu2device4xi['MAX2WORKITEM2'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '9A-'
        except: 
            message2print = "{(Step 9Z1/70) yielded" + "; max2workitem2-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '9Z1-' 
    
    

    if 'MAX2SIZE4WORKGROUP' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 10/70) - MAX2SIZE4WORKGROUP
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['MAX2SIZE4WORKGROUP'] = task4init2npu['MAX2SIZE4WORKGROUP']
            
            message2print = "{(Step 10A/70) initialized" + "; max2size4workgroup-initialized-by-init2npu4xi to: " + str(npu2device4xi['MAX2SIZE4WORKGROUP'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '10A-'
        except: 
            message2print = "{(Step 10Z1/70) yielded" + "; max2size4workgroup-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '10Z1-' 
    
    

    if 'PREFERRED2WIDTHCHAR4VECTOR' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 11/70) - PREFERRED2WIDTHCHAR4VECTOR
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['PREFERRED2WIDTHCHAR4VECTOR'] = task4init2npu['PREFERRED2WIDTHCHAR4VECTOR']
            
            message2print = "{(Step 11A/70) initialized" + "; preferred2widthchar4vector-initialized-by-init2npu4xi to: " + str(npu2device4xi['PREFERRED2WIDTHCHAR4VECTOR'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '11A-'
        except: 
            message2print = "{(Step 11Z1/70) yielded" + "; preferred2widthchar4vector-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '11Z1-' 
    
    

    if 'PREFERRED2WIDTHSHORT4VECTOR' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 12/70) - PREFERRED2WIDTHSHORT4VECTOR
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['PREFERRED2WIDTHSHORT4VECTOR'] = task4init2npu['PREFERRED2WIDTHSHORT4VECTOR']
            
            message2print = "{(Step 12A/70) initialized" + "; preferred2widthshort4vector-initialized-by-init2npu4xi to: " + str(npu2device4xi['PREFERRED2WIDTHSHORT4VECTOR'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '12A-'
        except: 
            message2print = "{(Step 12Z1/70) yielded" + "; preferred2widthshort4vector-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '12Z1-' 
        
    

    if 'PREFERRED2WIDTHINT4VECTOR' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 13/70) - PREFERRED2WIDTHINT4VECTOR
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['PREFERRED2WIDTHINT4VECTOR'] = task4init2npu['PREFERRED2WIDTHINT4VECTOR']
            
            message2print = "{(Step 13A/70) initialized" + "; preferred2widthint4vector-initialized-by-init2npu4xi to: " + str(npu2device4xi['PREFERRED2WIDTHINT4VECTOR'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '13A-'
        except: 
            message2print = "{(Step 13Z1/70) yielded" + "; preferred2widthint4vector-inpu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '13Z1-' 
    
    

    if 'PREFERRED2WIDTHLONG4VECTOR' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 14/70) - PREFERRED2WIDTHLONG4VECTOR
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['PREFERRED2WIDTHLONG4VECTOR'] = task4init2npu['PREFERRED2WIDTHLONG4VECTOR']
            
            message2print = "{(Step 14A/70) initialized" + "; preferred2widthlong4vector-initialized-by-init2npu4xi to: " + str(npu2device4xi['PREFERRED2WIDTHLONG4VECTOR'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '14A-'
        except: 
            message2print = "{(Step 14Z1/70) yielded" + "; preferred2widthlong4vector-pu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '14Z1-' 
    
    

    if 'PREFERRED2WIDTHFLOAT4VECTOR' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 15/70) - PREFERRED2WIDTHFLOAT4VECTOR
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['PREFERRED2WIDTHFLOAT4VECTOR'] = task4init2npu['PREFERRED2WIDTHFLOAT4VECTOR']
            
            message2print = "{(Step 15A/70) initialized" + "; preferred2widthfloat4vector-initialized-by-init2npu4xi to: " + str(npu2device4xi['PREFERRED2WIDTHFLOAT4VECTOR'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '15A-'
        except: 
            message2print = "{(Step 15Z1/70) yielded" + "; preferred2widthfloat4vector-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '15Z1-' 
        
                                        

    if 'PREFERRED2WIDTHDOUBLE4VECTOR' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 16/70) - PREFERRED2WIDTHDOUBLE4VECTOR
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['PREFERRED2WIDTHDOUBLE4VECTOR'] = task4init2npu['PREFERRED2WIDTHDOUBLE4VECTOR']
            
            message2print = "{(Step 16A/70) initialized" + "; preferred2widthdouble4vector-initialized-by-init2npu4xi to: " + str(npu2device4xi['PREFERRED2WIDTHDOUBLE4VECTOR'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '16A-'
        except: 
            message2print = "{(Step 16Z1/70) yielded" + "; preferred2widthdouble4vector-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '16Z1-' 
    
    

    if 'NATIVE2WIDTHCHAR4VECTOR' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 17/70) - NATIVE2WIDTHCHAR4VECTOR
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['NATIVE2WIDTHCHAR4VECTOR'] = task4init2npu['NATIVE2WIDTHCHAR4VECTOR']
            
            message2print = "{(Step 17A/70) initialized" + "; native2widthchar4vector-initialized-by-init2npu4xi to: " + str(npu2device4xi['NATIVE2WIDTHCHAR4VECTOR'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '17A-'
        except: 
            message2print = "{(Step 17Z1/70) yielded" + "; native2widthchar4vector-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '17Z1-' 
    
    

    if 'NATIVE2WIDTHSHORT4VECTOR' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 18/70) - NATIVE2WIDTHSHORT4VECTOR
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['NATIVE2WIDTHSHORT4VECTOR'] = task4init2npu['NATIVE2WIDTHSHORT4VECTOR']
            
            message2print = "{(Step 18A/70) initialized" + "; native2widthshort4vector-initialized-by-init2npu4xi to: " + str(npu2device4xi['NATIVE2WIDTHSHORT4VECTOR'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '18A-'
        except: 
            message2print = "{(Step 18Z1/70) yielded" + "; native2widthshort4vector-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '18Z1-' 
    
    

    if 'NATIVE2WIDTHINT4VECTOR' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 19/70) - NATIVE2WIDTHINT4VECTOR
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['NATIVE2WIDTHINT4VECTOR'] = task4init2npu['NATIVE2WIDTHINT4VECTOR']
            
            message2print = "{(Step 19A/70) initialized" + "; native2widthint4vector-initialized-by-init2npu4xi to: " + str(npu2device4xi['NATIVE2WIDTHINT4VECTOR'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '19A-'
        except: 
            message2print = "{(Step 19Z1/70) yielded" + "; native2widthint4vector-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '19Z1-' 
    
    

    if 'NATIVE2WIDTHLONG4VECTOR' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 20/70) - NATIVE2WIDTHLONG4VECTOR
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['NATIVE2WIDTHLONG4VECTOR'] = task4init2npu['NATIVE2WIDTHLONG4VECTOR']
            
            message2print = "{(Step 20A/70) initialized" + "; native2widthlong4vector-initialized-by-init2npu4xi to: " + str(npu2device4xi['NATIVE2WIDTHLONG4VECTOR'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '20A-'
        except: 
            message2print = "{(Step 20Z1/70) yielded" + "; native2widthlong4vector-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '20Z1-' 
    
    

    if 'NATIVE2WIDTHFLOAT4VECTOR' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 21/70) - NATIVE2WIDTHFLOAT4VECTOR
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['NATIVE2WIDTHFLOAT4VECTOR'] = task4init2npu['NATIVE2WIDTHFLOAT4VECTOR']
            
            message2print = "{(Step 21A/70) initialized" + "; native2widthfloat4vector-initialized-by-init2npu4xi to: " + str(npu2device4xi['NATIVE2WIDTHFLOAT4VECTOR'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '21A-'
        except: 
            message2print = "{(Step 21Z1/70) yielded" + "; native2widthfloat4vector-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '21Z1-' 
        
    

    if 'NATIVE2WIDTHDOUBLE4VECTOR' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 22/70) - NATIVE2WIDTHDOUBLE4VECTOR
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['NATIVE2WIDTHDOUBLE4VECTOR'] = task4init2npu['NATIVE2WIDTHDOUBLE4VECTOR']
            
            message2print = "{(Step 22A/70) initialized" + "; native2widthdouble4vector-initialized-by-init2npu4xi to: " + str(npu2device4xi['NATIVE2WIDTHDOUBLE4VECTOR'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '22A-'
        except: 
            message2print = "{(Step 22Z1/70) yielded" + "; native2widthdouble4vector-pu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '22Z1-' 
    
    

    if 'MAX2FREQUENCY4CLOCK' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 23/70) - MAX2FREQUENCY4CLOCK
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['MAX2FREQUENCY4CLOCK'] = task4init2npu['MAX2FREQUENCY4CLOCK']
            
            message2print = "{(Step 23A/70) initialized" + "; max2frequency4clock-initialized-by-init2npu4xi to: " + str(npu2device4xi['MAX2FREQUENCY4CLOCK'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '23A-'
        except: 
            message2print = "{(Step 23Z1/70) yielded" + "; max2frequency4clock-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '23Z1-' 
    
    

    if 'BITS2ADDRESS' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 24/70) - BITS2ADDRESS
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['BITS2ADDRESS'] = task4init2npu['BITS2ADDRESS']
            
            message2print = "{(Step 24A/70) initialized" + "; bits2address-initialized-by-init2npu4xi to: " + str(npu2device4xi['BITS2ADDRESS'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '24A-'
        except: 
            message2print = "{(Step 24Z1/70) yielded" + "; bits2address-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '24Z1-' 
        
    

    if 'MAX2ALLOCATION4MEMORY' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 25/70) - MAX2ALLOCATION4MEMORY
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['MAX2ALLOCATION4MEMORY'] = task4init2npu['MAX2ALLOCATION4MEMORY']
            
            message2print = "{(Step 25A/70) initialized" + "; max2allocation4memory-initialized-by-init2npu4xi to: " + str(npu2device4xi['MAX2ALLOCATION4MEMORY'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '25A-'
        except: 
            message2print = "{(Step 25Z1/70) yielded" + "; max2allocation4memory-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '25Z1-' 
    
               

    if 'SUPPORT2IMAGE' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 26/70) - SUPPORT2IMAGE
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['SUPPORT2IMAGE'] = task4init2npu['SUPPORT2IMAGE']
            
            message2print = "{(Step 26A/70) initialized" + "; support2image-initialized-by-init2npu4xi to: " + str(npu2device4xi['SUPPORT2IMAGE'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '26A-'
        except: 
            message2print = "{(Step 26Z1/70) yielded" + "; support2image-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '26Z1-' 
    
    

    if 'MAX2SIZE4KERNELARGUMENT' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 27/70) - MAX2SIZE4KERNELARGUMENT
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['MAX2SIZE4KERNELARGUMENT'] = task4init2npu['MAX2SIZE4KERNELARGUMENT']
            
            message2print = "{(Step 27A/70) initialized" + "; max2size4kernelargument-initialized-by-init2npu4xi to: " + str(npu2device4xi['MAX2SIZE4KERNELARGUMENT'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '27A-'
        except: 
            message2print = "{(Step 27Z1/70) yielded" + "; max2size4kernelargument-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '27Z1-' 
    
    

    if 'ALIGNMENT2ADDRESS4BASE' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 28/70) - ALIGNMENT2ADDRESS4BASE
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['ALIGNMENT2ADDRESS4BASE'] = task4init2npu['ALIGNMENT2ADDRESS4BASE']
            
            message2print = "{(Step 28A/70) initialized" + "; alignment2address4base-initialized-by-init2npu4xi to: " + str(npu2device4xi['ALIGNMENT2ADDRESS4BASE'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '28A-'
        except: 
            message2print = "{(Step 28Z1/70) yielded" + "; alignment2address4base-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '28Z1-' 
    
    

    if 'MINIMUM2ALIGNMENT4DATATYPE' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 29/70) - MINIMUM2ALIGNMENT4DATATYPE
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['MINIMUM2ALIGNMENT4DATATYPE'] = task4init2npu['MINIMUM2ALIGNMENT4DATATYPE']
            
            message2print = "{(Step 29A/70) initialized" + "; minimum2alignment4datatype-initialized-by-init2npu4xi to: " + str(npu2device4xi['MINIMUM2ALIGNMENT4DATATYPE'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '29A-'
        except: 
            message2print = "{(Step 29Z1/70) yielded" + "; minimum2alignment4datatype-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '29Z1-' 
    
    

    if 'DENORMS2SINGLEPRECISION4FLOATINGPOINTCAPABILITY' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 30/70) - DENORMS2SINGLEPRECISION4FLOATINGPOINTCAPABILITY
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['DENORMS2SINGLEPRECISION4FLOATINGPOINTCAPABILITY'] = task4init2npu['DENORMS2SINGLEPRECISION4FLOATINGPOINTCAPABILITY']
            
            message2print = "{(Step 30A/70) initialized" + "; denorms2singleprecision4floatingpointcapability-initialized-by-init2npu4xi to: " + str(npu2device4xi['DENORMS2SINGLEPRECISION4FLOATINGPOINTCAPABILITY'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '30A-'
        except: 
            message2print = "{(Step 30Z1/70) yielded" + "; denorms2singleprecision4floatingpointcapability-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '30Z1-' 
    
    

    if 'QUIET2NANS' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 31/70) - QUIET2NANS
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['QUIET2NANS'] = task4init2npu['QUIET2NANS']
            
            message2print = "{(Step 31A/70) initialized" + "; quiet2nans-initialized-by-init2npu4xi to: " + str(npu2device4xi['QUIET2NANS'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '31A-'
        except: 
            message2print = "{(Step 31Z1/70) yielded" + "; quiet2nans-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '31Z1-' 
        
    

    if 'ROUND2NEAREST4EVEN' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 32/70) - ROUND2NEAREST4EVEN
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['ROUND2NEAREST4EVEN'] = task4init2npu['ROUND2NEAREST4EVEN']
            
            message2print = "{(Step 32A/70) initialized" + "; round2nearest4even-initialized-by-init2npu4xi to: " + str(npu2device4xi['ROUND2NEAREST4EVEN'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '32A-'
        except: 
            message2print = "{(Step 32Z1/70) yielded" + "; round2nearest4even-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '32Z1-' 
    
    

    if 'ROUND2ZERO' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 33/70) - ROUND2ZERO
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['ROUND2ZERO'] = task4init2npu['ROUND2ZERO']
            
            message2print = "{(Step 33A/70) initialized" + "; round2zero-initialized-by-init2npu4xi to: " + str(npu2device4xi['ROUND2ZERO'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '33A-'
        except: 
            message2print = "{(Step 33Z1/70) yielded" + "; round2zero-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '33Z1-' 
        
    

    if 'ROUND2+VE3INFINITY' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 34/70) - ROUND2+VE3INFINITY
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['ROUND2+VE3INFINITY'] = task4init2npu['ROUND2+VE3INFINITY']
            
            message2print = "{(Step 34A/70) initialized" + "; round2+ve3infinity-initialized-by-init2npu4xi to: " + str(npu2device4xi['ROUND2+VE3INFINITY'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '34A-'
        except: 
            message2print = "{(Step 34Z1/70) yielded" + "; round2+ve3infinity-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '34Z1-' 
    
    

    if 'IEEE754-2008FUSED2MULTIPLY-ADD' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 35/70) - IEEE754-2008FUSED2MULTIPLY-ADD
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['IEEE754-2008FUSED2MULTIPLY-ADD'] = task4init2npu['IEEE754-2008FUSED2MULTIPLY-ADD']
            
            message2print = "{(Step 35A/70) initialized" + "; ieee754-2008fused2multiply-add-initialized-by-init2npu4xi to: " + str(npu2device4xi['IEEE754-2008FUSED2MULTIPLY-ADD'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '35A-'
        except: 
            message2print = "{(Step 35Z1/70) yielded" + "; ieee754-2008fused2multiply-add-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '35Z1-' 
    
               

    if 'TYPE4CACHE' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 36/70) - TYPE4CACHE
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['TYPE4CACHE'] = task4init2npu['TYPE4CACHE']
            
            message2print = "{(Step 36A/70) initialized" + "; type4cache-initialized-by-init2npu4xi to: " + str(npu2device4xi['TYPE4CACHE'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '36A-'
        except: 
            message2print = "{(Step 36Z1/70) yielded" + "; type4cache-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '36Z1-' 
        
    

    if 'SIZE2LINE4CACHE' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 37/70) - SIZE2LINE4CACHE
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['SIZE2LINE4CACHE'] = task4init2npu['SIZE2LINE4CACHE']
            
            message2print = "{(Step 37A/70) initialized" + "; size2line4cache-initialized-by-init2npu4xi to: " + str(npu2device4xi['SIZE2LINE4CACHE'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '37A-'
        except: 
            message2print = "{(Step 37Z1/70) yielded" + "; size2line4cache-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '37Z1-' 
    
    

    if 'SIZE2CACHE' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 38/70) - SIZE2CACHE
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['SIZE2CACHE'] = task4init2npu['SIZE2CACHE']
            
            message2print = "{(Step 38A/70) initialized" + "; size2cache-initialized-by-init2npu4xi to: " + str(npu2device4xi['SIZE2CACHE'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '38A-'
        except: 
            message2print = "{(Step 38Z1/70) yielded" + "; size2cache-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '38Z1-' 
    
    

    if 'SIZE2MEMORY4GLOBAL' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 39/70) - SIZE2MEMORY4GLOBAL
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['SIZE2MEMORY4GLOBAL'] = task4init2npu['SIZE2MEMORY4GLOBAL']
            
            message2print = "{(Step 39A/70) initialized" + "; size2memory4global-initialized-by-init2npu4xi to: " + str(npu2device4xi['SIZE2MEMORY4GLOBAL'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '39A-'
        except: 
            message2print = "{(Step 39Z1/70) yielded" + "; size2memory4global-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '39Z1-' 
    
    

    if 'SIZE2BUFFER4CONSTANT' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 40/70) - SIZE2BUFFER4CONSTANT
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['SIZE2BUFFER4CONSTANT'] = task4init2npu['SIZE2BUFFER4CONSTANT']
            
            message2print = "{(Step 40A/70) initialized" + "; size2buffer4constant-initialized-by-init2npu4xi to: " + str(npu2device4xi['SIZE2BUFFER4CONSTANT'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '40A-'
        except: 
            message2print = "{(Step 40Z1/70) yielded" + "; size2buffer4constant-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '40Z1-' 
    
    

    if 'MAX2NUMBER4CONSTANTARGS' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 41/70) - MAX2NUMBER4CONSTANTARGS
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['MAX2NUMBER4CONSTANTARGS'] = task4init2npu['MAX2NUMBER4CONSTANTARGS']
            
            message2print = "{(Step 41A/70) initialized" + "; max2number4constantargs-initialized-by-init2npu4xi to: " + str(npu2device4xi['MAX2NUMBER4CONSTANTARGS'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '41A-'
        except: 
            message2print = "{(Step 41Z1/70) yielded" + "; max2number4constantargs-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '41Z1-' 
        
    

    if 'TYPE2MEMORY4LOCAL' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 42/70) - TYPE2MEMORY4LOCAL
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['TYPE2MEMORY4LOCAL'] = task4init2npu['TYPE2MEMORY4LOCAL']
            
            message2print = "{(Step 42A/70) initialized" + "; type2memory4local-initialized-by-init2npu4xi to: " + str(npu2device4xi['TYPE2MEMORY4LOCAL'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '42A-'
        except: 
            message2print = "{(Step 42Z1/70) yielded" + "; type2memory4local-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '42Z1-' 
    
    

    if 'SIZE2MEMORY4LOCAL' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 43/70) - SIZE2MEMORY4LOCAL
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['SIZE2MEMORY4LOCAL'] = task4init2npu['SIZE2MEMORY4LOCAL']
            
            message2print = "{(Step 43A/70) initialized" + "; size2memory4local-initialized-by-init2npu4xi to: " + str(npu2device4xi['SIZE2MEMORY4LOCAL'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '43A-'
        except: 
            message2print = "{(Step 43Z1/70) yielded" + "; size2memory4local-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '43Z1-' 
    
    

    if 'SIZE2PREFERREDWORKGROUPMULTIPLE4KERNEL' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 44/70) - SIZE2PREFERREDWORKGROUPMULTIPLE4KERNEL
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['SIZE2PREFERREDWORKGROUPMULTIPLE4KERNEL'] = task4init2npu['SIZE2PREFERREDWORKGROUPMULTIPLE4KERNEL']
            
            message2print = "{(Step 44A/70) initialized" + "; size2preferredworkgroupmultiple4kernel-initialized-by-init2npu4xi to: " + str(npu2device4xi['SIZE2PREFERREDWORKGROUPMULTIPLE4KERNEL'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '44A-'
        except: 
            message2print = "{(Step 44Z1/70) yielded" + "; size2preferredworkgroupmultiple4kernel-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '44Z1-' 
    
    

    if 'SUPPORT2CORRECTION4ERROR' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 45/70) - SUPPORT2CORRECTION4ERROR
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['SUPPORT2CORRECTION4ERROR'] = task4init2npu['SUPPORT2CORRECTION4ERROR']
            
            message2print = "{(Step 45A/70) initialized" + "; support2correction4error-initialized-by-init2npu4xi to: " + str(npu2device4xi['SUPPORT2CORRECTION4ERROR'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '45A-'
        except: 
            message2print = "{(Step 45Z1/70) yielded" + "; support2correction4error-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '45Z1-' 
    
               

    if 'MEMORY2UNIFIED4HOSTANDDEVICE' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 46/70) - MEMORY2UNIFIED4HOSTANDDEVICE
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['MEMORY2UNIFIED4HOSTANDDEVICE'] = task4init2npu['MEMORY2UNIFIED4HOSTANDDEVICE']
            
            message2print = "{(Step 46A/70) initialized" + "; memory2unified4hostanddevice-initialized-by-init2npu4xi to: " + str(npu2device4xi['MEMORY2UNIFIED4HOSTANDDEVICE'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '46A-'
        except: 
            message2print = "{(Step 46Z1/70) yielded" + "; memory2unified4hostanddevice-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '46Z1-' 
    
    

    if 'RESOLUTION2TIMER4PROFILING' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 47/70) - RESOLUTION2TIMER4PROFILING
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['RESOLUTION2TIMER4PROFILING'] = task4init2npu['RESOLUTION2TIMER4PROFILING']
            
            message2print = "{(Step 47A/70) initialized" + "; resolution2timer4profiling-initialized-by-init2npu4xi to: " + str(npu2device4xi['RESOLUTION2TIMER4PROFILING'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '47A-'
        except: 
            message2print = "{(Step 47Z1/70) yielded" + "; resolution2timer4profiling-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '47Z1-' 
    
    

    if 'ENDIANESS2DEVICE' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 48/70) - ENDIANESS2DEVICE
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['ENDIANESS2DEVICE'] = task4init2npu['ENDIANESS2DEVICE']
            
            message2print = "{(Step 48A/70) initialized" + "; endianess2device-initialized-by-init2npu4xi to: " + str(npu2device4xi['ENDIANESS2DEVICE'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '48A-'
        except: 
            message2print = "{(Step 48Z1/70) yielded" + "; endianess2device-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '48Z1-' 
    
    

    if 'AVAILABLE' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 49/70) - AVAILABLE
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['AVAILABLE'] = task4init2npu['AVAILABLE']
            
            message2print = "{(Step 49A/70) initialized" + "; available-initialized-by-init2npu4xi to: " + str(npu2device4xi['AVAILABLE'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '49A-'
        except: 
            message2print = "{(Step 49Z1/70) yielded" + "; available-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '49Z1-' 
        
    

    if 'AVAILABLE2COMPILER' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 50/70) - AVAILABLE2COMPILER
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['AVAILABLE2COMPILER'] = task4init2npu['AVAILABLE2COMPILER']
            
            message2print = "{(Step 50A/70) initialized" + "; available2compiler-initialized-by-init2npu4xi to: " + str(npu2device4xi['AVAILABLE2COMPILER'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '50A-'
        except: 
            message2print = "{(Step 50Z1/70) yielded" + "; available2compiler-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '50Z1-' 
    
    

    if 'EXECUTE2KERNELS4OPENCL' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 51/70) - EXECUTE2KERNELS4OPENCL
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['EXECUTE2KERNELS4OPENCL'] = task4init2npu['EXECUTE2KERNELS4OPENCL']
            
            message2print = "{(Step 51A/70) initialized" + "; execute2kernels4opencl-initialized-by-init2npu4xi to: " + str(npu2device4xi['EXECUTE2KERNELS4OPENCL'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '51A-'
        except: 
            message2print = "{(Step 51Z1/70) yielded" + "; execute2kernels4opencl-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '51Z1-' 
        
    

    if 'EXECUTE2FUNCTION4NATIVE' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 52/70) - EXECUTE2FUNCTION4NATIVE
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['EXECUTE2FUNCTION4NATIVE'] = task4init2npu['EXECUTE2FUNCTION4NATIVE']
            
            message2print = "{(Step 52A/70) initialized" + "; execute2function4native-initialized-by-init2npu4xi to: " + str(npu2device4xi['EXECUTE2FUNCTION4NATIVE'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '52A-'
        except: 
            message2print = "{(Step 52Z1/70) yielded" + "; execute2function4native-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '52Z1-' 
    
    

    if 'OUT-OF-ORDER2QUEUE' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 53/70) - OUT-OF-ORDER2QUEUE
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['OUT-OF-ORDER2QUEUE'] = task4init2npu['OUT-OF-ORDER2QUEUE']
            
            message2print = "{(Step 53A/70) initialized" + "; out-of-order2queue-initialized-by-init2npu4xi to: " + str(npu2device4xi['OUT-OF-ORDER2QUEUE'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '53A-'
        except: 
            message2print = "{(Step 53Z1/70) yielded" + "; out-of-order2queue-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '53Z1-' 
        
    

    if 'PROFILING2QUEUE' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 54/70) - PROFILING2QUEUE
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['PROFILING2QUEUE'] = task4init2npu['PROFILING2QUEUE']
            
            message2print = "{(Step 54A/70) initialized" + "; profiling2queue-initialized-by-init2npu4xi to: " + str(npu2device4xi['PROFILING2QUEUE'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '54A-'
        except: 
            message2print = "{(Step 54Z1/70) yielded" + "; profiling2queue-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '54Z1-' 
    
    

    if 'ID2PLATFORM' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 55/70) - ID2PLATFORM
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['ID2PLATFORM'] = task4init2npu['ID2PLATFORM']
            
            message2print = "{(Step 55A/70) initialized" + "; id2platform-initialized-by-init2npu4xi to: " + str(npu2device4xi['ID2PLATFORM'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '55A-'
        except: 
            message2print = "{(Step 55Z1/70) yielded" + "; id2platform-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '55Z1-' 
    
               

    if 'VENDOR' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 56/70) - VENDOR
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['VENDOR'] = task4init2npu['VENDOR']
            
            message2print = "{(Step 56A/70) initialized" + "; vendor-initialized-by-init2npu4xi to: " + str(npu2device4xi['VENDOR'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '56A-'
        except: 
            message2print = "{(Step 56Z1/70) yielded" + "; vendor-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '56Z1-' 
        
    

    if 'VERSION2DRIVER' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 57/70) - VERSION2DRIVER
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['VERSION2DRIVER'] = task4init2npu['VERSION2DRIVER']
            
            message2print = "{(Step 57A/70) initialized" + "; version2driver-initialized-by-init2npu4xi to: " + str(npu2device4xi['VERSION2DRIVER'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '57A-'
        except: 
            message2print = "{(Step 57Z1/70) yielded" + "; version2driver-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '57Z1-' 
    
    

    if 'PROFILE' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 58/70) - PROFILE
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['PROFILE'] = task4init2npu['PROFILE']
            
            message2print = "{(Step 58A/70) initialized" + "; profile-initialized-by-init2npu4xi to: " + str(npu2device4xi['PROFILE'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '58A-'
        except: 
            message2print = "{(Step 58Z1/70) yielded" + "; profile-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '58Z1-' 
    
    

    if 'VERSION' in keys2task:    
        try: 
            # -----------------------------------------------------------------------------------------
            # (Step 59/70) - VERSION
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['VERSION'] = task4init2npu['VERSION']
            
            message2print = "{(Step 59A/70) initialized" + "; version-initialized-by-init2npu4xi to: " + str(npu2device4xi['VERSION'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '59A-'
        except: 
            message2print = "{(Step 59Z1/70) yielded" + "; version-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '59Z1-' 
    
    

    if 'EXTENSIONS' in keys2task:    
        try:
            # -----------------------------------------------------------------------------------------
            # (Step 60/70) - EXTENSIONS
            # -----------------------------------------------------------------------------------------               
            npu2device4xi['EXTENSIONS'] = task4init2npu['EXTENSIONS']
            
            message2print = "{(Step 60A/70) initialized" + "; extensions-initialized-by-init2npu4xi to: " + str(npu2device4xi['EXTENSIONS'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2ack  = code2ack + '60A-'
        except: 
            message2print = "{(Step 60Z1/70) yielded" + "; extensions-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '60Z1-' 
    
                   
    # -----------------------------------------------------------------------------------------
    # (Step 33/3)           
    # -----------------------------------------------------------------------------------------
    npu2device4xi ['ACK2RETURN']  = code2ack
    npu2device4xi ['NACK2RETURN'] = code2nack
    
    message2print = "{(Step 33/70) returning" + "; npu2device4xi-returning-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"  
    print4xi(class2print, method2print, message2print)                                                              
    # {'RESOLUTION2TIMER4PROFILING': 318,
    #  'ID2PLATFORM': '0000000001509568',
    #  'PROFILING2QUEUE': 'ACK',
    #  'EXECUTE2KERNELS4OPENCL': 'ACK',
    #  'NATIVE2WIDTHLONG4VECTOR': 2,
    #  'MAX2UNITS4COMPUTE': 4,
    #  'SIZE2MEMORY4GLOBAL': 3221225472,
    #  'NATIVE2WIDTHFLOAT4VECTOR': 4,
    #  'MAX2SIZE4WORKGROUP': 1024,
    #  'PREFERRED2WIDTHCHAR4VECTOR': 16,
    #  'SIZE2CACHE': 65536,
    #  'IEEE754-2008FUSED2MULTIPLY-ADD': 'NACK',
    #  'TYPE4CACHE': 'Read/Write',
    #  'PREFERRED2WIDTHINT4VECTOR': 4,
    #  'SIZE2PREFERREDWORKGROUPMULTIPLE4KERNEL': 1,
    #  'NATIVE2WIDTHINT4VECTOR': 4,
    #  'SIZE2BUFFER4CONSTANT': 65536,
    #  'EXECUTE2FUNCTION4NATIVE': 'ACK',
    #  'PREFERRED2WIDTHDOUBLE4VECTOR': 0,
    #  'MAX2NUMBER4CONSTANTARGS': 8,
    #  'VERSION2DRIVER': '2.0',
    #  'EXTENSIONS': 'cl_amd_fp64 cl_khr_global_int32_base_atomics cl_khr_global_int32_extended_atomics cl_khr_local_int32_base_atomics cl_khr_local_int32_extended_atomics cl_khr_int64_base_atomics cl_khr_int64_extended_atomics cl_khr_byte_addressable_store cl_khr_gl_sharing cl_ext_device_fission cl_amd_device_attribute_query cl_amd_media_ops cl_amd_popcnt cl_amd_printf cl_khr_d3d10_sharing',
    #  'AVAILABLE2COMPILER': 'ACK',
    #  'MAX2DIMENSIONS4WORKITEMS': 3,
    #  'SUPPORT2CORRECTION4ERROR': 0,
    #  'BITS2ADDRESS': 64,
    #  'AVAILABLE': 'ACK',
    #  'SIZE2MEMORY4LOCAL': 32768,
    #  'VENDOR': 'AuthenticAMD',
    #  'SUPPORT2IMAGE': 'NACK',
    #  'MAX2SIZE4KERNELARGUMENT': 4096,
    #  'OUT-OF-ORDER2QUEUE': 'NACK',
    #  'ALIGNMENT2ADDRESS4BASE': 1024,
    #  'PROFILE': 'FULL_PROFILE',
    #  'TYPE2MEMORY4LOCAL': 'Global',
    #  'PREFERRED2WIDTHFLOAT4VECTOR': 4,
    #  'PREFERRED2WIDTHLONG4VECTOR': 2,
    #  'MAX2FREQUENCY4CLOCK': 3210,
    #  'PREFERRED2WIDTHSHORT4VECTOR': 8,
    #  'ID': 4033,
    #  'ACK2RETURN': ' 1C1D1E1F1D2A3A4A5A6A7A8A9A10A11A12A13A14A15A16A17A18A19A20A21A22A23A24A25A26A27A28A29A30A31A32A33A34A35A36A37A38A39A40A41A42A43A44A45A46A47A48A49A50A51A52A53A54A55A56A57A58A59A60A',
    #  'MAX2WORKITEM2': 1024,
    #  'NATIVE2WIDTHDOUBLE4VECTOR': 0,
    #  'ROUND2ZERO': 'ACK', 
    #  'NAME': 'AMD64 Family 16 Model 4 Stepping 2,
    #  AuthenticAMD',
    #  'MAX2WORKITEM1': 1024,
    #  'MAX2WORKITEM0': 1024,
    #  'SIZE2LINE4CACHE': 64,
    #  'MAX2ALLOCATION4MEMORY': 1073741824,
    #  'NATIVE2WIDTHCHAR4VECTOR': 16,
    #  'QUIET2NANS': 'ACK',
    #  'NATIVE2WIDTHSHORT4VECTOR': 8,
    #  'ROUND2NEAREST4EVEN': 'ACK',
    #  'VERSION': 'OpenCL 1.1 ATI-Stream-v2.3 (451)',
    #  'NACK2RETURN': ' ',
    #  'MEMORY2UNIFIED4HOSTANDDEVICE': 1,
    #  'ENDIANESS2DEVICE': 'Little',
    #  'MINIMUM2ALIGNMENT4DATATYPE': 128,
    #  'ROUND2+VE3INFINITY': 'ACK',
    #  'TYPE': 'CL_DEVICE_TYPE_NPU',
    #  'DENORMS2SINGLEPRECISION4FLOATINGPOINTCAPABILITY': 'ACK'
    # }; time: 05:35:08 05/03/11 Pacific Daylight Time}


    
    return npu2device4xi
            
#</function4xi> 

# -------------------------------------------------------------------------------------------------
#<function4xi function = "set2npu4xi" usage = "
#
#   # example 1:
#   task4set2npu = {}
#   task4set2npu['ID'] = 4098
#   task4set2npu['TYPE'] = 'CL_DEVICE_TYPE_NPU'
#   task4set2npu['MAX2UNITS4COMPUTE'] = 2                                                                      # 2 CORES
#   
#   try:                               
#       response4set2npu = cc2xi.set2npu(task4set2npu)                                                       
#       print('(Step 7B/33) OF NPU4XI5TEST - RESPONSE4SET2NPU : ', response4set2npu)                     # {'NACK2RETURN': ' 4E', 'ACK2RETURN': ' 2A3A4A4C4D', 
#                                                                                                                 #         'TYPE': 'CL_DEVICE_TYPE_NPU', 'ID': 4098, 'MAX2UNITS4COMPUTE': 2} 
#   except:
#       print('(Step 7Z1/33) OF NPU4XI5TEST *** FAILED TO SET NPU ID AND TYPE ', time4xi())   
#         

#">

# -------------------------------------------------------------------------------------------------   
def set2npu4xi(task4set2npu=None):

    '''
    sets npu2device4xi
    '''
    global npu2device4xi  
    
    # -----------------------------------------------------------------------------------------
    # (Step 1/33) PARAMETERS           
    # -----------------------------------------------------------------------------------------          
    class2print = "set2npu4xi"
    method2print = "set2npu4xi"

    message2print = "{(Step 1A/33) started" + "; set2npu4xi-started: " + str(set2npu4xi)  + "; time: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)                                                              #  
  
             
    message2print = "{(Step 1B/33) passed" + "; task4set2npu-to-set2npu4xi: " + str(task4set2npu) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)                                                              
    # {'RESOLUTION2TIMER4PROFILING': 3188,
    #  'ID2PLATFORM': '00000000015095688',
    #  'PROFILING2QUEUE': 'ACK8',
    #  'EXECUTE2KERNELS4OPENCL': 'ACK8',
    #  'NATIVE2WIDTHLONG4VECTOR': 28,
    #  'MAX2WORKITEM2': 10248,
    #  'NATIVE2WIDTHFLOAT4VECTOR': 48,
    #  'MAX2SIZE4WORKGROUP': 10248,
    #  'NATIVE2WIDTHSHORT4VECTOR': 88,
    #  'PREFERRED2WIDTHCHAR4VECTOR': 168,
    #  'SIZE2CACHE': 655368,
    #  'NATIVE2WIDTHDOUBLE4VECTOR': 8,
    #  'IEEE754-2008FUSED2MULTIPLY-ADD': 'NACK8',
    #  'TYPE4CACHE': 'Read/Write8',
    #  'SUPPORT2IMAGE': 'NACK8',
    #  'SIZE2PREFERREDWORKGROUPMULTIPLE4KERNEL': 18,
    #  'NATIVE2WIDTHINT4VECTOR': 48,
    #  'EXECUTE2FUNCTION4NATIVE': 'ACK8',
    #  'PREFERRED2WIDTHDOUBLE4VECTOR': 8,
    #  'MAX2NUMBER4CONSTANTARGS': 88,
    #  'VERSION2DRIVER': '2.08',
    #  'EXTENSIONS': 'cl_amd_fp648 cl_khr_global_int32_base_atomics cl_khr_global_int32_extended_atomics cl_khr_local_int32_base_atomics cl_khr_local_int32_extended_atomics cl_khr_int64_base_atomics cl_khr_int64_extended_atomics cl_khr_byte_addressable_store cl_khr_gl_sharing cl_ext_device_fission cl_amd_device_attribute_query cl_amd_media_ops cl_amd_popcnt cl_amd_printf cl_khr_d3d10_sharing',
    #  'AVAILABLE2COMPILER': 'ACK8',
    #  'MAX2DIMENSIONS4WORKITEMS': 38,
    #  'BITS2ADDRESS': 648,
    #  'AVAILABLE': 'ACK8',
    #  'SIZE2MEMORY4LOCAL': 327688,
    #  'VENDOR': 'AuthenticAMD8',
    #  'SIZE2BUFFER4CONSTANT': 655368,
    #  'MAX2SIZE4KERNELARGUMENT': 40968,
    #  'OUT-OF-ORDER2QUEUE': 'NACK8',
    #  'ALIGNMENT2ADDRESS4BASE': 10248,
    #  'TYPE2MEMORY4LOCAL': 'Global8',
    #  'PREFERRED2WIDTHFLOAT4VECTOR': 48,
    #  'PREFERRED2WIDTHLONG4VECTOR': 28,
    #  'MAX2UNITS4COMPUTE': 48,
    #  'PREFERRED2WIDTHSHORT4VECTOR': 88,
    #  'ID': 40338,
    #  'SIZE2MEMORY4GLOBAL': 32212254728,
    #  'SUPPORT2CORRECTION4ERROR': 8,
    #  'PROFILE': 'FULL_PROFILE8',
    #  'ROUND2ZERO': 'ACK8',
    #  'NAME': 'AMD64 Family 16 Model 4 Stepping 2 AuthenticAMD8',
    #  'MAX2WORKITEM1': 10248,
    #  'MAX2FREQUENCY4CLOCK': 32108,
    #  'SIZE2LINE4CACHE': 648,
    #  'MAX2ALLOCATION4MEMORY': 10737418248,
    #  'MAX2WORKITEM0': 10248,
    #  'QUIET2NANS': 'ACK8',
    #  'PREFERRED2WIDTHINT4VECTOR': 48,
    #  'ROUND2NEAREST4EVEN': 'ACK8',
    #  'VERSION': 'OpenCL 1.1 ATI-Stream-v2.3 (4518)',
    #  'MEMORY2UNIFIED4HOSTANDDEVICE': 18,
    #  'ENDIANESS2DEVICE': 'Little8',
    #  'MINIMUM2ALIGNMENT4DATATYPE': 1288,
    #  'ROUND2+VE3INFINITY': 'ACK8',
    #  'TYPE': 'CL_DEVICE_TYPE_NPU8',
    #  'DENORMS2SINGLEPRECISION4FLOATINGPOINTCAPABILITY': 'ACK8',
    #  'NATIVE2WIDTHCHAR4VECTOR': 168
    # }; time: 06:35:29 05/03/11 Pacific Daylight Time}
 

             
    code2ack  = ' '
    code2nack = ' '

    if npu2device4xi is None:
        npu2device4xi = init2npu4xi()                                                                         # INITIALIZE IF NO PARAMETERS GIVEN                       

        
            
    try:
        # -----------------------------------------------------------------------------
        # (Step 2/33) - ID
        # ----------------------------------------------------------------------------- 
        npu2device4xi ['ID'] = task4set2npu ['ID']
        message2print = "{(Step 2A/33) set" + "; id-cpu-set-by-set2npu4xi to: " + str(npu2device4xi ['ID'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                                                          # 40338
        code2ack  = code2ack + '2A-'
    except:
        message2print = "{(Step 2Z1/70) yielded" + "; id-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        
    try:
        # -----------------------------------------------------------------------------
        # (Step 3/33) - TYPE
        # -----------------------------------------------------------------------------             
        npu2device4xi ['TYPE'] = task4set2npu ['TYPE']
        message2print = "{(Step 3A/33) set" + "; type-cpu-set-by-set2npu4xi to: " + str(npu2device4xi ['TYPE'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                                                          # CL_DEVICE_TYPE_NPU8
        code2ack  = code2ack + '3A-'
    except:
        message2print = "{(Step 3Z1/70) yielded" + "; type-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)         

        
    try:
        # -----------------------------------------------------------------------------------------    
        # (Step 4/33) - MAX COMPUTE UNITS
        # -----------------------------------------------------------------------------------------             
        cores2xi = cpu_corecount4xi()                                                                               # GET THE NUMBER OF NPU CORES AVAILABLE
        
        message2print = "{(Step 4A/33) got" + "; cores2xi-got-by-set2npu4xi to: " + str(cores2xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                                                          #  
        code2ack  = code2ack + '4A-'
        
        if task4set2npu ['MAX2UNITS4COMPUTE'] <= 0:                                                              # TOO FEW CORES GIVEN FOR OPENCL OPERATIONS!
            npu2device4xi ['MAX2UNITS4COMPUTE'] = cores2xi
            
            message2print = "{(Step 4B/33) set" + "; max2units4compute-set-by-set2npu4xi to: " + str(npu2device4xi ['MAX2UNITS4COMPUTE'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)                                                      #  
            code2ack  = code2ack + '4B-'
        else:            
            npu2device4xi ['MAX2UNITS4COMPUTE'] = task4set2npu ['MAX2UNITS4COMPUTE']
            
            message2print = "{(Step 4C/33) set" + "; max2units4compute-set-by-set2npu4xi to: " + str(npu2device4xi ['MAX2UNITS4COMPUTE'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)                                                      # 48 
            code2ack  = code2ack + '4C-'        
        
        
        if cores2xi > npu2device4xi ['MAX2UNITS4COMPUTE']:                                                       # NOT SO MANY CORES AVAILABLE FOR OPENCL OPERATIONS 
            message2print = "{(Step 4D/33) set" + "; max2units4compute-set-by-set2npu4xi to: " + str(npu2device4xi ['MAX2UNITS4COMPUTE'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)                                                      #  
            code2ack  = code2ack + '4D-'
    
            message2print = "{(Step 4E/33) warned" + "; cores2xi-warned-by-set2npu4xi: " + " ** " + str(cores2xi)  + " ** " + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            code2nack  = code2nack + '4E-'  
                    
        
        if cores2xi < npu2device4xi ['MAX2UNITS4COMPUTE']:                                                       # TOO MANY CORES WANTED FOR OPENCL OPERATIONS    
            npu2device4xi ['MAX2UNITS4COMPUTE'] = cores2xi
            message2print = "{(Step 4F/33) set" + "; max2units4compute-set-by-set2npu4xi to: " + str(npu2device4xi ['MAX2UNITS4COMPUTE'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)                                                      # 4 
            code2ack  = code2ack + '4F-'
    
            message2print = "{(Step 4G/33) warned" + "; cores2xi-warned-by-set2npu4xi: " + " ** " + str(cores2xi)  + " ** " + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)                                                      # ** 4 **
            code2nack  = code2nack + '4G-'  
        
        if cores2xi == npu2device4xi ['MAX2UNITS4COMPUTE']:                                                      # ALL CORES FOR OPENCL OPERATIONS     
            npu2device4xi ['MAX2UNITS4COMPUTE'] = cores2xi
            message2print = "{(Step 4H/33) set" + "; max2units4compute-set-by-set2npu4xi to: " + str(npu2device4xi ['MAX2UNITS4COMPUTE'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)                                                      # 4 
            code2ack  = code2ack + '4H-'
            
                                                      
    except:
        try:
            npu2device4xi ['MAX2UNITS4COMPUTE'] = cores2xi                                                       # USE CORE AMOUNT GIVEN BY OS
            message2print = "{(Step 4I/33) set" + "; max2units4compute-set-by-set2npu4xi to: " + str(npu2device4xi ['MAX2UNITS4COMPUTE'])  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)                                                      #  
            code2ack  = code2ack + '4I-'
        
        except:
            message2print = "{(Step 4Z1/33) yielded" + "; max2units4compute-npu2device4xi-yielded-by-init2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)  
            code2nack  = code2nack + '4Z1-'     
 
            
    try:
        # -----------------------------------------------------------------------------
        # (Step 5/33) - NAME
        # ----------------------------------------------------------------------------- 
        npu2device4xi ['NAME'] = task4set2npu ['NAME']
        message2print = "{(Step 5A/33) set" + "; name-cpu-set-by-set2npu4xi to: " + str(npu2device4xi ['NAME'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                                                          # AMD64 Family 16 Model 4 Stepping 2 AuthenticAMD8
        code2ack  = code2ack + '5A-'
    except:
        message2print = "{(Step 5Z1/70) yielded" + "; name-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                      

    try:
        # -----------------------------------------------------------------------------------------
        # (Step 6/70) - MAX2DIMENSIONS4WORKITEMS
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['MAX2DIMENSIONS4WORKITEMS'] = task4set2npu['MAX2DIMENSIONS4WORKITEMS']
        
        message2print = "{(Step 6A/70) set" + "; max2dimensions4workitems-set-by-set2npu4xi to: " + str(npu2device4xi['MAX2DIMENSIONS4WORKITEMS'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print) 
        code2ack  = code2ack + '6A-'
    except: 
        message2print = "{(Step 6Z1/70) yielded" + "; max2dimensions4workitems-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '6Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 7/70) - MAX2WORKITEM0
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['MAX2WORKITEM0'] = task4set2npu['MAX2WORKITEM0']
        
        message2print = "{(Step 7A/70) set" + "; max2workitem0-set-by-set2npu4xi to: " + str(npu2device4xi['MAX2WORKITEM0'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '7A-'
    except: 
        message2print = "{(Step 7Z1/70) yielded" + "; max2workitem0-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '7Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 8/70) - MAX2WORKITEM1
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['MAX2WORKITEM1'] = task4set2npu['MAX2WORKITEM1']
        
        message2print = "{(Step 8A/70) set" + "; max2workitem1-set-by-set2npu4xi to: " + str(npu2device4xi['MAX2WORKITEM1'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '8A-'
    except: 
        message2print = "{(Step 8Z1/70) yielded" + "; max2workitem1-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '8Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 9/70) - MAX2WORKITEM2
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['MAX2WORKITEM2'] = task4set2npu['MAX2WORKITEM2']
        
        message2print = "{(Step 9A/70) set" + "; max2workitem2-set-by-set2npu4xi to: " + str(npu2device4xi['MAX2WORKITEM2'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '9A-'
    except: 
        message2print = "{(Step 9Z1/70) yielded" + "; max2workitem2-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '9Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 10/70) - MAX2SIZE4WORKGROUP
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['MAX2SIZE4WORKGROUP'] = task4set2npu['MAX2SIZE4WORKGROUP']
        
        message2print = "{(Step 10A/70) set" + "; max2size4workgroup-set-by-set2npu4xi to: " + str(npu2device4xi['MAX2SIZE4WORKGROUP'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '10A-'
    except: 
        message2print = "{(Step 10Z1/70) yielded" + "; max2size4workgroup-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '10Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 11/70) - PREFERRED2WIDTHCHAR4VECTOR
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['PREFERRED2WIDTHCHAR4VECTOR'] = task4set2npu['PREFERRED2WIDTHCHAR4VECTOR']
        
        message2print = "{(Step 11A/70) set" + "; preferred2widthchar4vector-set-by-set2npu4xi to: " + str(npu2device4xi['PREFERRED2WIDTHCHAR4VECTOR'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '11A-'
    except: 
        message2print = "{(Step 11Z1/70) yielded" + "; preferred2widthchar4vector-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '11Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 12/70) - PREFERRED2WIDTHSHORT4VECTOR
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['PREFERRED2WIDTHSHORT4VECTOR'] = task4set2npu['PREFERRED2WIDTHSHORT4VECTOR']
        
        message2print = "{(Step 12A/70) set" + "; preferred2widthshort4vector-set-by-set2npu4xi to: " + str(npu2device4xi['PREFERRED2WIDTHSHORT4VECTOR'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '12A-'
    except: 
        message2print = "{(Step 12Z1/70) yielded" + "; preferred2widthshort4vector-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '12Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 13/70) - PREFERRED2WIDTHINT4VECTOR
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['PREFERRED2WIDTHINT4VECTOR'] = task4set2npu['PREFERRED2WIDTHINT4VECTOR']
        
        message2print = "{(Step 13A/70) set" + "; preferred2widthint4vector-set-by-set2npu4xi to: " + str(npu2device4xi['PREFERRED2WIDTHINT4VECTOR'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '13A-'
    except: 
        message2print = "{(Step 13Z1/70) yielded" + "; preferred2widthint4vector-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '13Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 14/70) - PREFERRED2WIDTHLONG4VECTOR
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['PREFERRED2WIDTHLONG4VECTOR'] = task4set2npu['PREFERRED2WIDTHLONG4VECTOR']
        
        message2print = "{(Step 14A/70) set" + "; preferred2widthlong4vector-set-by-set2npu4xi to: " + str(npu2device4xi['PREFERRED2WIDTHLONG4VECTOR'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '14A-'
    except: 
        message2print = "{(Step 14Z1/70) yielded" + "; preferred2widthlong4vector-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '14Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 15/70) - PREFERRED2WIDTHFLOAT4VECTOR
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['PREFERRED2WIDTHFLOAT4VECTOR'] = task4set2npu['PREFERRED2WIDTHFLOAT4VECTOR']
        
        message2print = "{(Step 15A/70) set" + "; preferred2widthfloat4vector-set-by-set2npu4xi to: " + str(npu2device4xi['PREFERRED2WIDTHFLOAT4VECTOR'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '15A-'
    except: 
        message2print = "{(Step 15Z1/70) yielded" + "; preferred2widthfloat4vector-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '15Z1-' 
    
                                        
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 16/70) - PREFERRED2WIDTHDOUBLE4VECTOR
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['PREFERRED2WIDTHDOUBLE4VECTOR'] = task4set2npu['PREFERRED2WIDTHDOUBLE4VECTOR']
        
        message2print = "{(Step 16A/70) set" + "; preferred2widthdouble4vector-set-by-set2npu4xi to: " + str(npu2device4xi['PREFERRED2WIDTHDOUBLE4VECTOR'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '16A-'
    except: 
        message2print = "{(Step 16Z1/70) yielded" + "; preferred2widthdouble4vector-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '16Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 17/70) - NATIVE2WIDTHCHAR4VECTOR
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['NATIVE2WIDTHCHAR4VECTOR'] = task4set2npu['NATIVE2WIDTHCHAR4VECTOR']
        
        message2print = "{(Step 17A/70) set" + "; native2widthchar4vector-set-by-set2npu4xi to: " + str(npu2device4xi['NATIVE2WIDTHCHAR4VECTOR'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '17A-'
    except: 
        message2print = "{(Step 17Z1/70) yielded" + "; native2widthchar4vector-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '17Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 18/70) - NATIVE2WIDTHSHORT4VECTOR
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['NATIVE2WIDTHSHORT4VECTOR'] = task4set2npu['NATIVE2WIDTHSHORT4VECTOR']
        
        message2print = "{(Step 18A/70) set" + "; native2widthshort4vector-set-by-set2npu4xi to: " + str(npu2device4xi['NATIVE2WIDTHSHORT4VECTOR'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '18A-'
    except: 
        message2print = "{(Step 18Z1/70) yielded" + "; native2widthshort4vector-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '18Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 19/70) - NATIVE2WIDTHINT4VECTOR
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['NATIVE2WIDTHINT4VECTOR'] = task4set2npu['NATIVE2WIDTHINT4VECTOR']
        
        message2print = "{(Step 19A/70) set" + "; native2widthint4vector-set-by-set2npu4xi to: " + str(npu2device4xi['NATIVE2WIDTHINT4VECTOR'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '19A-'
    except: 
        message2print = "{(Step 19Z1/70) yielded" + "; native2widthint4vector-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '19Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 20/70) - NATIVE2WIDTHLONG4VECTOR
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['NATIVE2WIDTHLONG4VECTOR'] = task4set2npu['NATIVE2WIDTHLONG4VECTOR']
        
        message2print = "{(Step 20A/70) set" + "; native2widthlong4vector-set-by-set2npu4xi to: " + str(npu2device4xi['NATIVE2WIDTHLONG4VECTOR'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '20A-'
    except: 
        message2print = "{(Step 20Z1/70) yielded" + "; native2widthlong4vector-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '20Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 21/70) - NATIVE2WIDTHFLOAT4VECTOR
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['NATIVE2WIDTHFLOAT4VECTOR'] = task4set2npu['NATIVE2WIDTHFLOAT4VECTOR']
        
        message2print = "{(Step 21A/70) set" + "; native2widthfloat4vector-set-by-set2npu4xi to: " + str(npu2device4xi['NATIVE2WIDTHFLOAT4VECTOR'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '21A-'
    except: 
        message2print = "{(Step 21Z1/70) yielded" + "; native2widthfloat4vector-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '21Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 22/70) - NATIVE2WIDTHDOUBLE4VECTOR
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['NATIVE2WIDTHDOUBLE4VECTOR'] = task4set2npu['NATIVE2WIDTHDOUBLE4VECTOR']
        
        message2print = "{(Step 22A/70) set" + "; native2widthdouble4vector-set-by-set2npu4xi to: " + str(npu2device4xi['NATIVE2WIDTHDOUBLE4VECTOR'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '22A-'
    except: 
        message2print = "{(Step 22Z1/70) yielded" + "; native2widthdouble4vector-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '22Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 23/70) - MAX2FREQUENCY4CLOCK
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['MAX2FREQUENCY4CLOCK'] = task4set2npu['MAX2FREQUENCY4CLOCK']
        
        message2print = "{(Step 23A/70) set" + "; max2frequency4clock-set-by-set2npu4xi to: " + str(npu2device4xi['MAX2FREQUENCY4CLOCK'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '23A-'
    except: 
        message2print = "{(Step 23Z1/70) yielded" + "; max2frequency4clock-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '23Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 24/70) - BITS2ADDRESS
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['BITS2ADDRESS'] = task4set2npu['BITS2ADDRESS']
        
        message2print = "{(Step 24A/70) set" + "; bits2address-set-by-set2npu4xi to: " + str(npu2device4xi['BITS2ADDRESS'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '24A-'
    except: 
        message2print = "{(Step 24Z1/70) yielded" + "; bits2address-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '24Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 25/70) - MAX2ALLOCATION4MEMORY
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['MAX2ALLOCATION4MEMORY'] = task4set2npu['MAX2ALLOCATION4MEMORY']
        
        message2print = "{(Step 25A/70) set" + "; max2allocation4memory-set-by-set2npu4xi to: " + str(npu2device4xi['MAX2ALLOCATION4MEMORY'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '25A-'
    except: 
        message2print = "{(Step 25Z1/70) yielded" + "; max2allocation4memory-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '25Z1-' 
    
               
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 26/70) - SUPPORT2IMAGE
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['SUPPORT2IMAGE'] = task4set2npu['SUPPORT2IMAGE']
        
        message2print = "{(Step 26A/70) set" + "; support2image-set-by-set2npu4xi to: " + str(npu2device4xi['SUPPORT2IMAGE'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '26A-'
    except: 
        message2print = "{(Step 26Z1/70) yielded" + "; support2image-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '26Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 27/70) - MAX2SIZE4KERNELARGUMENT
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['MAX2SIZE4KERNELARGUMENT'] = task4set2npu['MAX2SIZE4KERNELARGUMENT']
        
        message2print = "{(Step 27A/70) set" + "; max2size4kernelargument-set-by-set2npu4xi to: " + str(npu2device4xi['MAX2SIZE4KERNELARGUMENT'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '27A-'
    except: 
        message2print = "{(Step 27Z1/70) yielded" + "; max2size4kernelargument-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '27Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 28/70) - ALIGNMENT2ADDRESS4BASE
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['ALIGNMENT2ADDRESS4BASE'] = task4set2npu['ALIGNMENT2ADDRESS4BASE']
        
        message2print = "{(Step 28A/70) set" + "; alignment2address4base-set-by-set2npu4xi to: " + str(npu2device4xi['ALIGNMENT2ADDRESS4BASE'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '28A-'
    except: 
        message2print = "{(Step 28Z1/70) yielded" + "; alignment2address4base-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '28Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 29/70) - MINIMUM2ALIGNMENT4DATATYPE
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['MINIMUM2ALIGNMENT4DATATYPE'] = task4set2npu['MINIMUM2ALIGNMENT4DATATYPE']
        
        message2print = "{(Step 29A/70) set" + "; minimum2alignment4datatype-set-by-set2npu4xi to: " + str(npu2device4xi['MINIMUM2ALIGNMENT4DATATYPE'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '29A-'
    except: 
        message2print = "{(Step 29Z1/70) yielded" + "; minimum2alignment4datatype-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '29Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 30/70) - DENORMS2SINGLEPRECISION4FLOATINGPOINTCAPABILITY
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['DENORMS2SINGLEPRECISION4FLOATINGPOINTCAPABILITY'] = task4set2npu['DENORMS2SINGLEPRECISION4FLOATINGPOINTCAPABILITY']
        
        message2print = "{(Step 30A/70) set" + "; denorms2singleprecision4floatingpointcapability-set-by-set2npu4xi to: " + str(npu2device4xi['DENORMS2SINGLEPRECISION4FLOATINGPOINTCAPABILITY'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '30A-'
    except: 
        message2print = "{(Step 30Z1/70) yielded" + "; denorms2singleprecision4floatingpointcapability-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '30Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 31/70) - QUIET2NANS
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['QUIET2NANS'] = task4set2npu['QUIET2NANS']
        
        message2print = "{(Step 31A/70) set" + "; quiet2nans-set-by-set2npu4xi to: " + str(npu2device4xi['QUIET2NANS'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '31A-'
    except: 
        message2print = "{(Step 31Z1/70) yielded" + "; quiet2nans-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '31Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 32/70) - ROUND2NEAREST4EVEN
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['ROUND2NEAREST4EVEN'] = task4set2npu['ROUND2NEAREST4EVEN']
        
        message2print = "{(Step 32A/70) set" + "; round2nearest4even-set-by-set2npu4xi to: " + str(npu2device4xi['ROUND2NEAREST4EVEN'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '32A-'
    except: 
        message2print = "{(Step 32Z1/70) yielded" + "; round2nearest4even-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '32Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 33/70) - ROUND2ZERO
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['ROUND2ZERO'] = task4set2npu['ROUND2ZERO']
        
        message2print = "{(Step 33A/70) set" + "; round2zero-set-by-set2npu4xi to: " + str(npu2device4xi['ROUND2ZERO'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '33A-'
    except: 
        message2print = "{(Step 33Z1/70) yielded" + "; round2zero-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '33Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 34/70) - ROUND2+VE3INFINITY
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['ROUND2+VE3INFINITY'] = task4set2npu['ROUND2+VE3INFINITY']
        
        message2print = "{(Step 34A/70) set" + "; round2+ve3infinity-set-by-set2npu4xi to: " + str(npu2device4xi['ROUND2+VE3INFINITY'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '34A-'
    except: 
        message2print = "{(Step 34Z1/70) yielded" + "; round2+ve3infinity-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '34Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 35/70) - IEEE754-2008FUSED2MULTIPLY-ADD
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['IEEE754-2008FUSED2MULTIPLY-ADD'] = task4set2npu['IEEE754-2008FUSED2MULTIPLY-ADD']
        
        message2print = "{(Step 35A/70) set" + "; ieee754-2008fused2multiply-add-set-by-set2npu4xi to: " + str(npu2device4xi['IEEE754-2008FUSED2MULTIPLY-ADD'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '35A-'
    except: 
        message2print = "{(Step 35Z1/70) yielded" + "; ieee754-2008fused2multiply-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '35Z1-' 
    
               
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 36/70) - TYPE4CACHE
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['TYPE4CACHE'] = task4set2npu['TYPE4CACHE']
        
        message2print = "{(Step 36A/70) set" + "; type4cache-set-by-set2npu4xi to: " + str(npu2device4xi['TYPE4CACHE'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '36A-'
    except: 
        message2print = "{(Step 36Z1/70) yielded" + "; type4cache-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '36Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 37/70) - SIZE2LINE4CACHE
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['SIZE2LINE4CACHE'] = task4set2npu['SIZE2LINE4CACHE']
        
        message2print = "{(Step 37A/70) set" + "; size2line4cache-set-by-set2npu4xi to: " + str(npu2device4xi['SIZE2LINE4CACHE'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '37A-'
    except: 
        message2print = "{(Step 37Z1/70) yielded" + "; size2line4cache-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '37Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 38/70) - SIZE2CACHE
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['SIZE2CACHE'] = task4set2npu['SIZE2CACHE']
        
        message2print = "{(Step 38A/70) set" + "; size2cache-set-by-set2npu4xi to: " + str(npu2device4xi['SIZE2CACHE'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '38A-'
    except: 
        message2print = "{(Step 38Z1/70) yielded" + "; size2cache-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '38Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 39/70) - SIZE2MEMORY4GLOBAL
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['SIZE2MEMORY4GLOBAL'] = task4set2npu['SIZE2MEMORY4GLOBAL']
        
        message2print = "{(Step 39A/70) set" + "; size2memory4global-set-by-set2npu4xi to: " + str(npu2device4xi['SIZE2MEMORY4GLOBAL'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '39A-'
    except: 
        message2print = "{(Step 39Z1/70) yielded" + "; size2memory4global-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '39Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 40/70) - SIZE2BUFFER4CONSTANT
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['SIZE2BUFFER4CONSTANT'] = task4set2npu['SIZE2BUFFER4CONSTANT']
        
        message2print = "{(Step 40A/70) set" + "; size2buffer4constant-set-by-set2npu4xi to: " + str(npu2device4xi['SIZE2BUFFER4CONSTANT'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '40A-'
    except: 
        message2print = "{(Step 40Z1/70) yielded" + "; size2buffer4constant-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '40Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 41/70) - MAX2NUMBER4CONSTANTARGS
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['MAX2NUMBER4CONSTANTARGS'] = task4set2npu['MAX2NUMBER4CONSTANTARGS']
        
        message2print = "{(Step 41A/70) set" + "; max2number4constantargs-set-by-set2npu4xi to: " + str(npu2device4xi['MAX2NUMBER4CONSTANTARGS'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '41A-'
    except: 
        message2print = "{(Step 41Z1/70) yielded" + "; max2number4constantargs-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '41Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 42/70) - TYPE2MEMORY4LOCAL
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['TYPE2MEMORY4LOCAL'] = task4set2npu['TYPE2MEMORY4LOCAL']
        
        message2print = "{(Step 42A/70) set" + "; type2memory4local-set-by-set2npu4xi to: " + str(npu2device4xi['TYPE2MEMORY4LOCAL'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '42A-'
    except: 
        message2print = "{(Step 42Z1/70) yielded" + "; type2memory4local-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '42Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 43/70) - SIZE2MEMORY4LOCAL
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['SIZE2MEMORY4LOCAL'] = task4set2npu['SIZE2MEMORY4LOCAL']
        
        message2print = "{(Step 43A/70) set" + "; size2memory4local-set-by-set2npu4xi to: " + str(npu2device4xi['SIZE2MEMORY4LOCAL'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '43A-'
    except: 
        message2print = "{(Step 43Z1/70) yielded" + "; size2memory4local-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '43Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 44/70) - SIZE2PREFERREDWORKGROUPMULTIPLE4KERNEL
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['SIZE2PREFERREDWORKGROUPMULTIPLE4KERNEL'] = task4set2npu['SIZE2PREFERREDWORKGROUPMULTIPLE4KERNEL']
        
        message2print = "{(Step 44A/70) set" + "; size2preferredworkgroupmultiple4kernel-set-by-set2npu4xi to: " + str(npu2device4xi['SIZE2PREFERREDWORKGROUPMULTIPLE4KERNEL'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '44A-'
    except: 
        message2print = "{(Step 44Z1/70) yielded" + "; size2preferredworkgroupmultiple4kernel-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '44Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 45/70) - SUPPORT2CORRECTION4ERROR
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['SUPPORT2CORRECTION4ERROR'] = task4set2npu['SUPPORT2CORRECTION4ERROR']
        
        message2print = "{(Step 45A/70) set" + "; support2correction4error-set-by-set2npu4xi to: " + str(npu2device4xi['SUPPORT2CORRECTION4ERROR'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '45A-'
    except: 
        message2print = "{(Step 45Z1/70) yielded" + "; support2correction4error-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '45Z1-' 
    
               
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 46/70) - MEMORY2UNIFIED4HOSTANDDEVICE
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['MEMORY2UNIFIED4HOSTANDDEVICE'] = task4set2npu['MEMORY2UNIFIED4HOSTANDDEVICE']
        
        message2print = "{(Step 46A/70) set" + "; memory2unified4hostanddevice-set-by-set2npu4xi to: " + str(npu2device4xi['MEMORY2UNIFIED4HOSTANDDEVICE'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '46A-'
    except: 
        message2print = "{(Step 46Z1/70) yielded" + "; memory2unified4hostanddevice-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '46Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 47/70) - RESOLUTION2TIMER4PROFILING
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['RESOLUTION2TIMER4PROFILING'] = task4set2npu['RESOLUTION2TIMER4PROFILING']
        
        message2print = "{(Step 47A/70) set" + "; resolution2timer4profiling-set-by-set2npu4xi to: " + str(npu2device4xi['RESOLUTION2TIMER4PROFILING'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '47A-'
    except: 
        message2print = "{(Step 47Z1/70) yielded" + "; resolution2timer4profiling-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '47Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 48/70) - ENDIANESS2DEVICE
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['ENDIANESS2DEVICE'] = task4set2npu['ENDIANESS2DEVICE']
        
        message2print = "{(Step 48A/70) set" + "; endianess2device-set-by-set2npu4xi to: " + str(npu2device4xi['ENDIANESS2DEVICE'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '48A-'
    except: 
        message2print = "{(Step 48Z1/70) yielded" + "; endianess2device-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '48Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 49/70) - AVAILABLE
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['AVAILABLE'] = task4set2npu['AVAILABLE']
        
        message2print = "{(Step 49A/70) set" + "; available-set-by-set2npu4xi to: " + str(npu2device4xi['AVAILABLE'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '49A-'
    except: 
        message2print = "{(Step 49Z1/70) yielded" + "; available-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '49Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 50/70) - AVAILABLE2COMPILER
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['AVAILABLE2COMPILER'] = task4set2npu['AVAILABLE2COMPILER']
        
        message2print = "{(Step 50A/70) set" + "; available2compiler-set-by-set2npu4xi to: " + str(npu2device4xi['AVAILABLE2COMPILER'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '50A-'
    except: 
        message2print = "{(Step 50Z1/70) yielded" + "; available2compiler-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '50Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 51/70) - EXECUTE2KERNELS4OPENCL
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['EXECUTE2KERNELS4OPENCL'] = task4set2npu['EXECUTE2KERNELS4OPENCL']
        
        message2print = "{(Step 51A/70) set" + "; execute2kernels4opencl-set-by-set2npu4xi to: " + str(npu2device4xi['EXECUTE2KERNELS4OPENCL'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '51A-'
    except: 
        message2print = "{(Step 51Z1/70) yielded" + "; execute2kernels4opencl-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '51Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 52/70) - EXECUTE2FUNCTION4NATIVE
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['EXECUTE2FUNCTION4NATIVE'] = task4set2npu['EXECUTE2FUNCTION4NATIVE']
        
        message2print = "{(Step 52A/70) set" + "; execute2function4native-set-by-set2npu4xi to: " + str(npu2device4xi['EXECUTE2FUNCTION4NATIVE'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '52A-'
    except: 
        message2print = "{(Step 52Z1/70) yielded" + "; execute2function4native-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '52Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 53/70) - OUT-OF-ORDER2QUEUE
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['OUT-OF-ORDER2QUEUE'] = task4set2npu['OUT-OF-ORDER2QUEUE']
        
        message2print = "{(Step 53A/70) set" + "; out-of-order2queue-set-by-set2npu4xi to: " + str(npu2device4xi['OUT-OF-ORDER2QUEUE'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '53A-'
    except: 
        message2print = "{(Step 53Z1/70) yielded" + "; out-of-order2queue-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '53Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 54/70) - PROFILING2QUEUE
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['PROFILING2QUEUE'] = task4set2npu['PROFILING2QUEUE']
        
        message2print = "{(Step 54A/70) set" + "; profiling2queue-set-by-set2npu4xi to: " + str(npu2device4xi['PROFILING2QUEUE'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '54A-'
    except: 
        message2print = "{(Step 54Z1/70) yielded" + "; profiling2queue-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '54Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 55/70) - ID2PLATFORM
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['ID2PLATFORM'] = task4set2npu['ID2PLATFORM']
        
        message2print = "{(Step 55A/70) set" + "; id2platform-set-by-set2npu4xi to: " + str(npu2device4xi['ID2PLATFORM'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '55A-'
    except: 
        message2print = "{(Step 55Z1/70) yielded" + "; id2platform-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '55Z1-' 
    
               
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 56/70) - VENDOR
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['VENDOR'] = task4set2npu['VENDOR']
        
        message2print = "{(Step 56A/70) set" + "; vendor-set-by-set2npu4xi to: " + str(npu2device4xi['VENDOR'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '56A-'
    except: 
        message2print = "{(Step 56Z1/70) yielded" + "; vendor-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '56Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 57/70) - VERSION2DRIVER
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['VERSION2DRIVER'] = task4set2npu['VERSION2DRIVER']
        
        message2print = "{(Step 57A/70) set" + "; version2driver-set-by-set2npu4xi to: " + str(npu2device4xi['VERSION2DRIVER'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '57A-'
    except: 
        message2print = "{(Step 57Z1/70) yielded" + "; version2driver-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '57Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 58/70) - PROFILE
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['PROFILE'] = task4set2npu['PROFILE']
        
        message2print = "{(Step 58A/70) set" + "; profile-set-by-set2npu4xi to: " + str(npu2device4xi['PROFILE'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '58A-'
    except: 
        message2print = "{(Step 58Z1/70) yielded" + "; profile-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '58Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 59/70) - VERSION
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['VERSION'] = task4set2npu['VERSION']
        
        message2print = "{(Step 59A/70) set" + "; version-set-by-set2npu4xi to: " + str(npu2device4xi['VERSION'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '59A-'
    except: 
        message2print = "{(Step 59Z1/70) yielded" + "; version-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '59Z1-' 
    
    
    
    try:
        # -----------------------------------------------------------------------------------------
        # (Step 60/70) - EXTENSIONS
        # -----------------------------------------------------------------------------------------               
        npu2device4xi['EXTENSIONS'] = task4set2npu['EXTENSIONS']
        
        message2print = "{(Step 60A/70) set" + "; extensions-set-by-set2npu4xi to: " + str(npu2device4xi['EXTENSIONS'])  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        code2ack  = code2ack + '60A-'
    except: 
        message2print = "{(Step 60Z1/70) yielded" + "; extensions-npu2device4xi-yielded-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        code2nack  = code2nack + '60Z1-'
         


            
    # -----------------------------------------------------------------------------------------
    # (Step 70/70)           
    # -----------------------------------------------------------------------------------------
    npu2device4xi ['ACK2RETURN']  = code2ack
    npu2device4xi ['NACK2RETURN'] = code2nack 
    
    message2print = "{(Step 70/70) returning" + "; npu2device4xi-returning-by-set2npu4xi: " + str(npu2device4xi) + "; time: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)                                                             
    return npu2device4xi

    #
    # {'RESOLUTION2TIMER4PROFILING': 318, 
    #  'ID2PLATFORM': '0000000001509568', 
    #  'PROFILING2QUEUE': 'ACK',
    #  'EXECUTE2KERNELS4OPENCL': 'ACK',
    #  'NATIVE2WIDTHLONG4VECTOR': 2,
    #  'MAX2UNITS4COMPUTE': 4, 
    #  'SIZE2MEMORY4GLOBAL': 3221225472,
    #  'NATIVE2WIDTHFLOAT4VECTOR': 4,
    #  'MAX2SIZE4WORKGROUP': 1024,
    #  'PREFERRED2WIDTHCHAR4VECTOR': 16,
    #  'SIZE2CACHE': 65536, 
    #  'IEEE754-2008FUSED2MULTIPLY-ADD': 'NACK',
    #  'TYPE4CACHE': 'Read/Write',
    #  'PREFERRED2WIDTHINT4VECTOR': 4,
    #  'SIZE2PREFERREDWORKGROUPMULTIPLE4KERNEL': 1, 
    #  'NATIVE2WIDTHINT4VECTOR': 4,
    #  'SIZE2BUFFER4CONSTANT': 65536,
    #  'EXECUTE2FUNCTION4NATIVE': 'ACK',
    #  'PREFERRED2WIDTHDOUBLE4VECTOR': 0,
    #  'MAX2NUMBER4CONSTANTARGS': 8, 
    #  'VERSION2DRIVER': '2.0',
    #  'EXTENSIONS': 'cl_amd_fp64 cl_khr_global_int32_base_atomics cl_khr_global_int32_extended_atomics cl_khr_local_int32_base_atomics cl_khr_local_int32_extended_atomics cl_khr_int64_base_atomics cl_khr_int64_extended_atomics cl_khr_byte_addressable_store cl_khr_gl_sharing cl_ext_device_fission cl_amd_device_attribute_query cl_amd_media_ops cl_amd_popcnt cl_amd_printf cl_khr_d3d10_sharing', 
    #  'AVAILABLE2COMPILER': 'ACK',
    #  'MAX2DIMENSIONS4WORKITEMS': 3,
    #  'SUPPORT2CORRECTION4ERROR': 0,
    #  'BITS2ADDRESS': 64,
    #  'AVAILABLE': 'ACK',
    #  'SIZE2MEMORY4LOCAL': 32768, 
    #  'VENDOR': 'AuthenticAMD',
    #  'SUPPORT2IMAGE': 'NACK',
    #  'MAX2SIZE4KERNELARGUMENT': 4096,
    #  'OUT-OF-ORDER2QUEUE': 'NACK',
    #  'ALIGNMENT2ADDRESS4BASE': 1024, 
    #  'PROFILE': 'FULL_PROFILE',
    #  'TYPE2MEMORY4LOCAL': 'Global',
    #  'PREFERRED2WIDTHFLOAT4VECTOR': 4,
    #  'PREFERRED2WIDTHLONG4VECTOR': 2,
    #  'MAX2FREQUENCY4CLOCK': 3210, 
    #  'PREFERRED2WIDTHSHORT4VECTOR': 8,
    #  'ID': 4098,
    #  'ACK2RETURN': ' 2A3A4A4I',
    #  'MAX2WORKITEM2': 1024, 
    #  'NATIVE2WIDTHDOUBLE4VECTOR': 0,
    #  'ROUND2ZERO': 'ACK',
    #  'NAME': 'AMD64 Family 16 Model 4 Stepping 2,
    #  AuthenticAMD',
    #  'MAX2WORKITEM1': 1024, 
    #  'MAX2WORKITEM0': 1024,
    #  'SIZE2LINE4CACHE': 64,
    #  'MAX2ALLOCATION4MEMORY': 1073741824,
    #  'NATIVE2WIDTHCHAR4VECTOR': 16, 
    #  'QUIET2NANS': 'ACK',
    #  'NATIVE2WIDTHSHORT4VECTOR': 8,
    #  'ROUND2NEAREST4EVEN': 'ACK',
    #  'VERSION': 'OpenCL 1.1 ATI-Stream-v2.3 (451)', 
    #  'NACK2RETURN': ' 6Z17Z18Z19Z110Z111Z112Z113Z114Z115Z116Z117Z118Z119Z120Z121Z122Z123Z124Z125Z126Z127Z128Z129Z130Z131Z132Z133Z134Z135Z136Z137Z138Z139Z140Z141Z142Z143Z144Z145Z146Z147Z148Z149Z150Z151Z152Z153Z154Z155Z156Z157Z158Z159Z160Z1', 
    #  'MEMORY2UNIFIED4HOSTANDDEVICE': 1,
    #  'ENDIANESS2DEVICE': 'Little',
    #  'MINIMUM2ALIGNMENT4DATATYPE': 128,
    #  'ROUND2+VE3INFINITY': 'ACK', 
    #  'TYPE': 'CL_DEVICE_TYPE_NPU',
    #  'DENORMS2SINGLEPRECISION4FLOATINGPOINTCAPABILITY': 'ACK'
    #  }; time: 06:06:10 05/03/11 Pacific Daylight Time}

            
#</function4xi>
 

# -------------------------------------------------------------------------------------------------
#<function4xi function = "get2npu4xi" usage = "
#
#   try:                               
#       response4get2npu = get2npu4xi()                                        
#                                                                                                                   
#   except:
#       ... 
#                          
#">

# -------------------------------------------------------------------------------------------------   
def get2npu4xi():

    '''
    gets npu2device4xi
    '''
    
    global npu2device4xi
    
    # -----------------------------------------------------------------------------------------
    # (Step 1/33)           
    # -----------------------------------------------------------------------------------------          
    class2print = "get2npu4xi"
    method2print = "get2npu4xi"

    message2print = "{(Step 1A/33) started" + "; get2npu4xi-started: " + str(get2npu4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)                                                              # 
    
    try: 
        if npu2device4xi is None:
            # -------------------------------------------------------------------------------------
            # INITIALIZE           
            # -------------------------------------------------------------------------------------           
            npu2xi = init2npu4xi()
            message2print = "{(Step 1B/33) initialized" + "; npu2xi-initialized-by-get2npu4xi to: " + str(npu2xi)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            #  
        else:
            npu2xi = npu2device4xi
            message2print = "{(Step 1C/33) got" + "; npu2xi-got-by-get2npu4xi: " + str(npu2xi)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)   
    

    except:
        try:
            # -------------------------------------------------------------------------------------
            # INITIALIZE           
            # -------------------------------------------------------------------------------------           
            npu2xi = init2npu4xi()
            message2print = "{(Step 1D/33) initialized" + "; npu2xi-initialized-by-get2npu4xi to: " + str(npu2xi)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            # 
        except:
            npu2xi = {}
            message2print = "{(Step 1Z1/70) yielded" + "; npu2xi-yielded-by-get2npu4xi: " + str(npu2xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)                  

    message2print = "{(Step 33/33) returning" + "; npu2xi-returning-by-get2npu4xi: " + str(npu2xi) + "; time: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)
    # {      'NACK2RETURN': ' ', 'ACK2RETURN': ' 1C1D1E1F2A3A4A', 
    #               'TYPE': 'CL_DEVICE_TYPE_NPU', 
    #                 'ID': 'NPU', 
    #  'MAX2UNITS4COMPUTE': 4
    # }; time: 07:54:07 05/02/11 Pacific Daylight Time}
                
    return npu2xi
            
#</function4xi> 
 
                                               
# =================================================================================================
#<class4xi class = "NPU4Xi" base = "object" child = "None"
#       synopsis = "offers methods for NPU processing unit" usage = "NPU processing unit"
#>

# =================================================================================================
class NPU4Xi(object): 
    ''' 
    NPU4Xi offers methods for NPU processing unit
    '''            

    #                                        
    # ---------------------------------------------------------------------------------------------
    # sharable class variables
    # ---------------------------------------------------------------------------------------------      
    #<share4xi share = " 
    classvariable2npu = cpu_corecount4xi()
    #"
    #/>
        
    # ---------------------------------------------------------------------------------------------
    # Public API of this class
    # ---------------------------------------------------------------------------------------------    
    #<expose4xi expose = "
    _exposed_ = (
    'init2npu',
    'get2npu',
    'set2npu',
    'sense',
    'reason',
    'ace')          
    #"
    #/>
 
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "init-of-NPU4Xi" usage = "
    # try:
    #     # ---------------------------------------------------------------------------------------------
    #     # CREATE OBJECT                        
    #     # ---------------------------------------------------------------------------------------------        
    #     cc2xi = NPU4Xi()
    #     print('(Step 5B/33) OF NPU4XI5TEST - CREATED NPU4XI OBJECT: ', cc2xi)                               # <npu2device4xi.NPU4Xi object at 0x000000000331B630> 
    # except:
    #     print('(Step 5Z/33) OF NPU4XI5TEST *** FAILED TO CREATE NPU4XI OBJECT')
    #">
    
    # ---------------------------------------------------------------------------------------------   
    def __init__(self, task4init2npu = None):
        '''
        _init__ method initializes NPU4Xi
        ''' 
        
        # -----------------------------------------------------------------------------------------
        # (Step 1/33)           
        # -----------------------------------------------------------------------------------------
                    
        class2print = "NPU4Xi"
        method2print = "__init__"
                     
        message2print = "{(Step 1A/33) started" + "; init-of-NPU4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                                                          # 

        message2print = "{(Step 1B/33) borning" + "; npu2device2xi-of-NPU4Xi-borning: " + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                                                          #   
                
        message2print = "{(Step 1C/33) inheriting" + "; object-inheriting-by-npu2device2xi-of-NPU4Xi: " + str(object)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                                                          # <class 'device4xi.object'>    
        
        message2print = "{(Step 1D/33) sharing" + "; classvariable2npu-sharing-by-npu2device2xi-of-NPU4Xi: " + str(NPU4Xi.classvariable2npu)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                                                          # 4                 
                                
        message2print = "{(Step 1E/33) passed" + "; task4init2npu-passed-to-init-of-NPU4Xi: " + str(task4init2npu) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                                                          # None                                 
        
        # -----------------------------------------------------------------------------------------
        # (Step 2/33)             
        # -----------------------------------------------------------------------------------------
        
        message2print = "{(Step 2A/33) passing" + "; task4init2npu-passing-to-init2npu4xi-by-init-of-NPU4Xi: " + str(task4init2npu) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                                                          # None   
        
        npu2device2xi = init2npu4xi(task4init2npu)
        
        message2print = "{(Step 2B/33) performed" + "; init2npu4xi-performed-by-init-of-NPU4Xi: " + str(init2npu4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                                                          # <function init2npu4xi at 0x00000000031C6F48>    
                        
        # -----------------------------------------------------------------------------------------
        # (Step 3/33)             
        # -----------------------------------------------------------------------------------------
        message2print = "{(Step 3A/33) activated" + "; npu2device2xi-of-NPU4Xi-activated: " + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                                                          # 
                
        message2print = "{(Step 3B/33) inherited" + "; object-inherited-by-npu2device2xi-of-NPU4Xi: " + str(object)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                                                          # <class 'device4xi.object'>   
        
        message2print = "{(Step 3C/33) shared" + "; classvariable2npu-shared-by-npu2device2xi-of-NPU4Xi: " + str(NPU4Xi.classvariable2npu)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                                                          # 4                
       
        message2print = "{(Step 3D/33) returning" + "; init-of-NPU4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)                                                          # 09:05:05 05/02/11 Pacific Daylight Time
        

    #</methodize4xi>
    

    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "init-of-NPU4Xi" usage = "initializes objects of NPU4Xi">
    
    # ---------------------------------------------------------------------------------------------   
    def init2npu(self, task4init2npu = None):
        '''
        init2npu method initializes objects of NPU4Xi
        ''' 
        
        # -----------------------------------------------------------------------------------------
        # (Step 1/33)           
        # -----------------------------------------------------------------------------------------              
        class2print = "NPU4Xi"
        method2print = "init2npu"
                     
        message2print = "{(Step 1A/33) started" + "; init-of-NPU4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
            
        message2print = "{(Step 1B/33) passed" + "; task4init2npu-passed-to-init-of-NPU4Xi: " + str(task4init2npu) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                                      
          
        # -----------------------------------------------------------------------------------------
        # (Step 2/33)           
        # -----------------------------------------------------------------------------------------
        message2print = "{(Step 2A/33) passing" + "; task4init2npu-passing-to-init2npu4xi-by-init-of-NPU4Xi: " + str(task4init2npu) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
                
  
        npu2device2xi = init2npu4xi(task4init2npu)

        message2print = "{(Step 2B/33) performed" + "; init2npu4xi-performed-by-init-of-NPU4Xi: " + str(init2npu4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)             
                                
        # -----------------------------------------------------------------------------------------
        # (Step 3/33)           
        # ----------------------------------------------------------------------------------------- 
        message2print = "{(Step 3/33) returning" + "; npu2device2xi-returning-by-init2npu-of-NPU4Xi: " + str(npu2device2xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)                                                          # 
 
                
        return npu2device2xi
                                
                            
    #</methodize4xi>
    

    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "set2npu-of-NPU4Xi" usage = "
    # task4set2npu = {}
    # task4set2npu['ID'] = 40984
    # task4set2npu['TYPE'] = 'CL_DEVICE_TYPE_NPU4'
    # task4set2npu['MAX2UNITS4COMPUTE'] = 4                                                                      # 4 CORES
    # task4set2npu['NAME'] = 'AMD Phenom(tm) II X4 955 Processor'                                                # OPENCL NAME 
    # 
    # try:                               
    #     response4set2npu = cc2xi.set2npu(task4set2npu)                                                        
    #     print('(Step 8B/33) OF NPU4XI5TEST - RESPONSE4SET2NPU : ', response4set2npu)                     # {      'NAME': 'AMD Phenom(tm) II X4 955 Processor', 
    #                                                                                                               #  'ACK2RETURN': ' 2A3A4A4C4H5A', 'NACK2RETURN': ' ', 
    #                                                                                                               #  'MAX2UNITS4COMPUTE': 4, 'TYPE': 'CL_DEVICE_TYPE_NPU4', 'ID': 40984}
    # 
    # except:
    #     print('(Step 8Z1/33) OF NPU4XI5TEST *** FAILED TO SET NPU ID AND TYPE ', time4xi())   
    #   
    #">
    
    # ---------------------------------------------------------------------------------------------   
    def set2npu(self, task4set2npu = None):
        '''
        set2npu method sets objects of NPU4Xi
        ''' 
        
        # -----------------------------------------------------------------------------------------
        # (Step 1/33)           
        # -----------------------------------------------------------------------------------------              
        class2print = "NPU4Xi"
        method2print = "set2npu"
                     
        message2print = "{(Step 1A/33) started" + "; set2npu-of-NPU4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
            
        message2print = "{(Step 1B/33) passed" + "; task4set2npu-passed-to-set2npu-of-NPU4Xi: " + str(task4set2npu) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                                                          
        # {'RESOLUTION2TIMER4PROFILING': 3188,
        #  'ID2PLATFORM': '00000000015095688',
        #  'PROFILING2QUEUE': 'ACK8',
        #  'EXECUTE2KERNELS4OPENCL': 'ACK8',
        #  'NATIVE2WIDTHLONG4VECTOR': 28,
        #  'MAX2WORKITEM2': 10248,
        #  'NATIVE2WIDTHFLOAT4VECTOR': 48,
        #  'MAX2SIZE4WORKGROUP': 10248,
        #  'NATIVE2WIDTHSHORT4VECTOR': 88,
        #  'PREFERRED2WIDTHCHAR4VECTOR': 168,
        #  'SIZE2CACHE': 655368,
        #  'NATIVE2WIDTHDOUBLE4VECTOR': 8,
        #  'IEEE754-2008FUSED2MULTIPLY-ADD': 'NACK8',
        #  'TYPE4CACHE': 'Read/Write8',
        #  'SUPPORT2IMAGE': 'NACK8',
        #  'SIZE2PREFERREDWORKGROUPMULTIPLE4KERNEL': 18,
        #  'NATIVE2WIDTHINT4VECTOR': 48,
        #  'EXECUTE2FUNCTION4NATIVE': 'ACK8',
        #  'PREFERRED2WIDTHDOUBLE4VECTOR': 8,
        #  'MAX2NUMBER4CONSTANTARGS': 88,
        #  'VERSION2DRIVER': '2.08',
        #  'EXTENSIONS': 'cl_amd_fp648 cl_khr_global_int32_base_atomics cl_khr_global_int32_extended_atomics cl_khr_local_int32_base_atomics cl_khr_local_int32_extended_atomics cl_khr_int64_base_atomics cl_khr_int64_extended_atomics cl_khr_byte_addressable_store cl_khr_gl_sharing cl_ext_device_fission cl_amd_device_attribute_query cl_amd_media_ops cl_amd_popcnt cl_amd_printf cl_khr_d3d10_sharing',
        #  'AVAILABLE2COMPILER': 'ACK8',
        #  'MAX2DIMENSIONS4WORKITEMS': 38,
        #  'BITS2ADDRESS': 648,
        #  'AVAILABLE': 'ACK8',
        #  'SIZE2MEMORY4LOCAL': 327688,
        #  'VENDOR': 'AuthenticAMD8',
        #  'SIZE2BUFFER4CONSTANT': 655368,
        #  'MAX2SIZE4KERNELARGUMENT': 40968,
        #  'OUT-OF-ORDER2QUEUE': 'NACK8',
        #  'ALIGNMENT2ADDRESS4BASE': 10248,
        #  'TYPE2MEMORY4LOCAL': 'Global8',
        #  'PREFERRED2WIDTHFLOAT4VECTOR': 48,
        #  'PREFERRED2WIDTHLONG4VECTOR': 28,
        #  'MAX2UNITS4COMPUTE': 48,
        #  'PREFERRED2WIDTHSHORT4VECTOR': 88,
        #  'ID': 40338,
        #  'SIZE2MEMORY4GLOBAL': 32212254728,
        #  'SUPPORT2CORRECTION4ERROR': 8,
        #  'PROFILE': 'FULL_PROFILE8',
        #  'ROUND2ZERO': 'ACK8',
        #  'NAME': 'AMD64 Family 16 Model 4 Stepping 2 AuthenticAMD8',
        #  'MAX2WORKITEM1': 10248,
        #  'MAX2FREQUENCY4CLOCK': 32108,
        #  'SIZE2LINE4CACHE': 648,
        #  'MAX2ALLOCATION4MEMORY': 10737418248,
        #  'MAX2WORKITEM0': 10248,
        #  'QUIET2NANS': 'ACK8',
        #  'PREFERRED2WIDTHINT4VECTOR': 48,
        #  'ROUND2NEAREST4EVEN': 'ACK8',
        #  'VERSION': 'OpenCL 1.1 ATI-Stream-v2.3 (4518)',
        #  'MEMORY2UNIFIED4HOSTANDDEVICE': 18,
        #  'ENDIANESS2DEVICE': 'Little8',
        #  'MINIMUM2ALIGNMENT4DATATYPE': 1288,
        #  'ROUND2+VE3INFINITY': 'ACK8',
        #  'TYPE': 'CL_DEVICE_TYPE_NPU8',
        #  'DENORMS2SINGLEPRECISION4FLOATINGPOINTCAPABILITY': 'ACK8',
        #  'NATIVE2WIDTHCHAR4VECTOR': 168
        #}; time: 06:35:29 05/03/11 Pacific Daylight Time}
                                                               
          
        # -----------------------------------------------------------------------------------------
        # (Step 2/33)           
        # -----------------------------------------------------------------------------------------
        message2print = "{(Step 2A/33) passing" + "; task4set2npu-passing-to-set2npu4xi-by-set2npu-of-NPU4Xi: " + str(task4set2npu) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)                                                               
        # {'RESOLUTION2TIMER4PROFILING': 3188,
        #  'ID2PLATFORM': '00000000015095688',
        #  'PROFILING2QUEUE': 'ACK8',
        #  'EXECUTE2KERNELS4OPENCL': 'ACK8',
        #  'NATIVE2WIDTHLONG4VECTOR': 28,
        #  'MAX2WORKITEM2': 10248,
        #  'NATIVE2WIDTHFLOAT4VECTOR': 48,
        #  'MAX2SIZE4WORKGROUP': 10248,
        #  'NATIVE2WIDTHSHORT4VECTOR': 88,
        #  'PREFERRED2WIDTHCHAR4VECTOR': 168,
        #  'SIZE2CACHE': 655368,
        #  'NATIVE2WIDTHDOUBLE4VECTOR': 8,
        #  'IEEE754-2008FUSED2MULTIPLY-ADD': 'NACK8',
        #  'TYPE4CACHE': 'Read/Write8',
        #  'SUPPORT2IMAGE': 'NACK8',
        #  'SIZE2PREFERREDWORKGROUPMULTIPLE4KERNEL': 18,
        #  'NATIVE2WIDTHINT4VECTOR': 48,
        #  'EXECUTE2FUNCTION4NATIVE': 'ACK8',
        #  'PREFERRED2WIDTHDOUBLE4VECTOR': 8,
        #  'MAX2NUMBER4CONSTANTARGS': 88,
        #  'VERSION2DRIVER': '2.08',
        #  'EXTENSIONS': 'cl_amd_fp648 cl_khr_global_int32_base_atomics cl_khr_global_int32_extended_atomics cl_khr_local_int32_base_atomics cl_khr_local_int32_extended_atomics cl_khr_int64_base_atomics cl_khr_int64_extended_atomics cl_khr_byte_addressable_store cl_khr_gl_sharing cl_ext_device_fission cl_amd_device_attribute_query cl_amd_media_ops cl_amd_popcnt cl_amd_printf cl_khr_d3d10_sharing',
        #  'AVAILABLE2COMPILER': 'ACK8',
        #  'MAX2DIMENSIONS4WORKITEMS': 38,
        #  'BITS2ADDRESS': 648,
        #  'AVAILABLE': 'ACK8',
        #  'SIZE2MEMORY4LOCAL': 327688,
        #  'VENDOR': 'AuthenticAMD8',
        #  'SIZE2BUFFER4CONSTANT': 655368,
        #  'MAX2SIZE4KERNELARGUMENT': 40968,
        #  'OUT-OF-ORDER2QUEUE': 'NACK8',
        #  'ALIGNMENT2ADDRESS4BASE': 10248,
        #  'TYPE2MEMORY4LOCAL': 'Global8',
        #  'PREFERRED2WIDTHFLOAT4VECTOR': 48,
        #  'PREFERRED2WIDTHLONG4VECTOR': 28,
        #  'MAX2UNITS4COMPUTE': 48,
        #  'PREFERRED2WIDTHSHORT4VECTOR': 88,
        #  'ID': 40338,
        #  'SIZE2MEMORY4GLOBAL': 32212254728,
        #  'SUPPORT2CORRECTION4ERROR': 8,
        #  'PROFILE': 'FULL_PROFILE8',
        #  'ROUND2ZERO': 'ACK8',
        #  'NAME': 'AMD64 Family 16 Model 4 Stepping 2 AuthenticAMD8',
        #  'MAX2WORKITEM1': 10248,
        #  'MAX2FREQUENCY4CLOCK': 32108,
        #  'SIZE2LINE4CACHE': 648,
        #  'MAX2ALLOCATION4MEMORY': 10737418248,
        #  'MAX2WORKITEM0': 10248,
        #  'QUIET2NANS': 'ACK8',
        #  'PREFERRED2WIDTHINT4VECTOR': 48,
        #  'ROUND2NEAREST4EVEN': 'ACK8',
        #  'VERSION': 'OpenCL 1.1 ATI-Stream-v2.3 (4518)',
        #  'MEMORY2UNIFIED4HOSTANDDEVICE': 18,
        #  'ENDIANESS2DEVICE': 'Little8',
        #  'MINIMUM2ALIGNMENT4DATATYPE': 1288,
        #  'ROUND2+VE3INFINITY': 'ACK8',
        #  'TYPE': 'CL_DEVICE_TYPE_NPU8',
        #  'DENORMS2SINGLEPRECISION4FLOATINGPOINTCAPABILITY': 'ACK8',
        #  'NATIVE2WIDTHCHAR4VECTOR': 168
        #  }; time: 06:35:29 05/03/11 Pacific Daylight Time}
        
  
        npu2device2xi = set2npu4xi(task4set2npu)

        message2print = "{(Step 2B/33) performed" + "; set2npu4xi-performed-by-set2npu-of-NPU4Xi: " + str(set2npu4xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)             
                                
        # -----------------------------------------------------------------------------------------
        # (Step 3/33)           
        # ----------------------------------------------------------------------------------------- 
       
        message2print = "{(Step 3A/33) returning" + "; npu2device2xi-returning-by-set2npu-of-NPU4Xi: " + str(npu2device2xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)                                                          # {      'NACK2RETURN': ' 4E', 'ACK2RETURN': ' 2A3A4A4C4D', 'TYPE': 'CL_DEVICE_TYPE_NPU', 'ID': 4098, 
                                                                                                                    #  'MAX2UNITS4COMPUTE': 2} 
                                                                                                                    # {       'NACK2RETURN': ' ', 'ACK2RETURN': ' 2A3A4A4C4H', 'TYPE': 'CL_DEVICE_TYPE_NPU4', 'ID': 40984, 
                                                                                                                    #   'MAX2UNITS4COMPUTE': 4}
                                                                                                                    
                
        return npu2device2xi
                                
                            
    #</methodize4xi>

    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "get2npu-of-NPU4Xi" usage = "
    # try:                               
    #     cpu12xi = cc2xi.get2npu()                                  
    #     print('(Step 12B/33) OF NPU4XI5TEST - GOT NPU: ', cpu12xi)                                          # {'NACK2RETURN': ' ', 'ACK2RETURN': ' 2A3A4A4C4H', 
    #                                                                                                               #         'TYPE': 'CL_DEVICE_TYPE_NPU4', 'ID': 40984, 'MAX2UNITS4COMPUTE': 4}
    # 
    # except:
    #     print('(Step 12Z/33) OF NPU4XI5TEST *** FAILED TO GET DEVICE')   
    
    # ">
    
    # ---------------------------------------------------------------------------------------------   
    def get2npu(self):
        '''
        get2npu method gets objects of NPU4Xi
        ''' 
        
        # -----------------------------------------------------------------------------------------
        # (Step 1/33)           
        # -----------------------------------------------------------------------------------------              
        class2print = "NPU4Xi"
        method2print = "get2npu"
                     
        message2print = "{(Step 1A/33) started" + "; get2npu-of-NPU4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
            

        # -----------------------------------------------------------------------------------------
        # (Step 2/33)           
        # ----------------------------------------------------------------------------------------- 
        npu2device2xi = get2npu4xi()
        
        message2print = "{(Step 2A/33) returning" + "; npu2device2xi-returning-by-get2npu-of-NPU4Xi: " + str(npu2device2xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)                                                          # {      'NACK2RETURN': ' ', 
                                                                                                                    #         'ACK2RETURN': ' 1C1D1E1F2A3A4A', 
                                                                                                                    #               'TYPE': 'CL_DEVICE_TYPE_NPU', 
                                                                                                                    #                 'ID': 'NPU', 
                                                                                                                    #  'MAX2UNITS4COMPUTE': 4}

 
                
        return npu2device2xi
                                
                            
    #</methodize4xi>                                     
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "sense-of-NPU4Xi" usage = "
    # try:
    #     print(cc2xi.sense())
    # 
    #     print('=' *33)          
    #     print('(Step 15B/33) OF NPU4XI5TEST - SENSED ', time4xi())                                             # {'object': <npu2device4xi.NPU4Xi object at 0x00000000033F1860>, 
    #                                                                                                               # 'classvariable2npu-of-NPU4Xi': 4}
    #     print('=' *33)
    # except:
    #     print('(Step 15Z/33) OF NPU4XI5TEST *** FAILED TO SENSE ', time4xi())    
    # 
    # ">
    
    # ---------------------------------------------------------------------------------------------
    def sense(self):
        '''
        method sense: senses NPU4Xi class objects
        '''
        
        # -----------------------------------------------------------------------------------------
        #
        # ----------------------------------------------------------------------------------------- 
        class2print = 'NPU4Xi'
        method2print = 'sense'
        
                     
        message2print = "{(Step 1A/33) started" + "; sense-of-NPU4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
        
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------  
        
        message2print = "{(Step 2A/33) sensing" + "; NPU4Xi-sensing-by-sense-of-NPU4Xi: " + str(NPU4Xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)         
                        
        
        # -----------------------------------------------------------------------------------------
        # get sensed knowledge for this object
        # -----------------------------------------------------------------------------------------        
        
        kb2xi = sense_object4xi(self)
        
        message2print = "{(Step 3A/33) got" + "; kb2xi-got-by-sense-of-NPU4Xi: " + str(kb2xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
                
        
        # -----------------------------------------------------------------------------------------
        # add knowledge specific to this object
        # format example: kb2xi['time2xi'] = time4xi() #adding time 
        # -----------------------------------------------------------------------------------------         
        try:
            kb2xi['classvariable2npu-of-NPU4Xi'] = NPU4Xi.classvariable2npu
        except:
            message2print = "{(Step 4A/33) yielded" + "; kb2xi-yielded-by-sense-of-NPU4Xi: " + str(kb2xi)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print) 
            
      
        message2print = "{(Step 5A/33) sensed" + "; NPU4Xi-sensed-by-sense-of-NPU4Xi: " + str(NPU4Xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)    
        
        # -----------------------------------------------------------------------------------------
        # 
        # -----------------------------------------------------------------------------------------         
        
        message2print = "{(Step 6A/33) returning" + "; kb2xi-returning-by-sense-of-NPU4Xi: " + str(kb2xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)                                                          # {'object': <npu2device4xi.NPU4Xi object at 0x00000000033F1860>, 
                                                                                                                    #  'classvariable2npu-of-NPU4Xi': 4} 

                                
          
        return kb2xi
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------        
    #</methodize4xi>
    
        
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "reason-of-NPU4Xi" usage = "
    # try:
    #     print(cc2xi.reason())
    # 
    #     print('=' *33)          
    #     print('(Step 17B/33) OF NPU4XI5TEST - REASONED ', time4xi())                                           # <npu2device4xi.NPU4Xi object at 0x00000000033F1860>, 'time-reason-of-NPU4Xi': '08:52:35 05/02/11 Pacific Daylight Time'}
    #     print('=' *33)       
    # except:
    #     print('(Step 17Z/33) OF NPU4XI5TEST *** FAILED TO REASON ', time4xi())     
    # ">
    
    # ---------------------------------------------------------------------------------------------
    def reason(self):
        '''
        method reason: reasons NPU4Xi class objects
        '''
        
        # -----------------------------------------------------------------------------------------
        #
        # ----------------------------------------------------------------------------------------- 
        class2print = 'NPU4Xi'
        method2print = 'reason'

                     
        message2print = "{(Step 1A/33) started" + "; reason-of-NPU4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
          
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------
        
        message2print = "{(Step 2A/33) reasoning" + "; NPU4Xi-reasoning-by-reason-of-NPU4Xi: " + str(NPU4Xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print) 
                
        
        # -----------------------------------------------------------------------------------------
        # get reasoned knowledge for this object
        # -----------------------------------------------------------------------------------------         
        
        kb4xi = reason_object4xi(self)
        
        
        message2print = "{(Step 3A/33) got" + "; kb4xi-got-by-reason-of-NPU4Xi: " + str(kb4xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
                
        
        # -----------------------------------------------------------------------------------------
        # add knowledge specific to this object
        # format example: kb4xi['time2xi'] = time4xi() #adding time 
        # -----------------------------------------------------------------------------------------          
        try:
            kb4xi['time-reason-of-NPU4Xi'] = time4xi() #adding time
        except:
            message2print = "{(Step 4Z/33) yielded" + "; kb4xi-yielded-by-reason-of-NPU4Xi: " + str(kb4xi)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print) 
        
          
        
        message2print = "{(Step 5A/33) reasoned" + "; NPU4Xi-reasoned-by-reason-of-NPU4Xi: " + str(NPU4Xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)        
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------        
        
        message2print = "{(Step 6A/33) returning" + "; kb4xi-returning-by-reason-of-NPU4Xi: " + str(kb4xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)                                                          # {'object-reason-object4xi': <npu2device4xi.NPU4Xi object at 0x00000000033F1860>, 
                                                                                                                    #    'time-reason-of-NPU4Xi': '08:52:35 05/02/11 Pacific Daylight Time'}
                                
          
        return kb4xi
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------            
    #</methodize4xi>
    
    
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "ace-of-NPU4Xi" usage = "
    # try:
    #     print(cc2xi.ace())
    # 
    #     print('=' *33)          
    #     print('(Step 21B/33) OF NPU4XI5TEST - ACED ', time4xi())                                               # kb8xi-returning-by-ace-of-NPU4Xi: {'cores-of-NPU4Xi': 4, 'object8xi': <npu2device4xi.NPU4Xi object at 0x00000000033F1860>}
    #     print('=' *33) 
    # except:
    #     print('(Step 21Z/33) OF NPU4XI5TEST *** FAILED TO ACE ', time4xi())      
    # 
    # ">
    
    # ---------------------------------------------------------------------------------------------
    def ace(self):
        '''
        method ace: aces NPU4Xi class objects 
        '''
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------       
        
        
        class2print = 'NPU4Xi'
        method2print = 'ace'
        
                     
        message2print = "{(Step 1A/33) started" + "; ace-of-NPU4Xi-started: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
              
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------
        
        message2print = "{(Step 2A/33) acing" + "; NPU4Xi-acing-by-ace-of-NPU4Xi: " + str(NPU4Xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)         
                    
        
        # -----------------------------------------------------------------------------------------
        # get aced knowledge for this object
        # -----------------------------------------------------------------------------------------        
        
        kb8xi = ace_object4xi(self)  
        
        message2print = "{(Step 3A/33) got" + "; kb8xi-got-by-ace-of-NPU4Xi: " + str(kb8xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
                


        # -----------------------------------------------------------------------------------------
        # add knowledge specific to this object
        # format example: kb8xi['time2xi'] = time4xi() #adding time 
        # -----------------------------------------------------------------------------------------              
        try:
             kb8xi['cores-of-NPU4Xi'] = NPU4Xi.classvariable2npu
        except:
             message2print = "{(Step 4A/33) yielded" + "; kb8xi-yielded-by-ace-of-NPU4Xi: " + str(kb8xi)  + "; time: " + time4xi() + "}"
             print4xi(class2print, method2print, message2print) 
  
        message2print = "{(Step 5A/33) aced" + "; NPU4Xi-aced-by-ace-of-NPU4Xi: " + str(NPU4Xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)         
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------        
        message2print = "{(Step 6A/33) returning" + "; kb8xi-returning-by-ace-of-NPU4Xi: " + str(kb8xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)                                                          # {'cores-of-NPU4Xi': 4, 'object8xi': <npu2device4xi.NPU4Xi object at 0x00000000033F1860>} 
                                  
        
        return kb8xi
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------            
    #</methodize4xi>
#</class4xi>
#</program4xi>

# -------------------------------------------------------------------------------------------------
# Recorded History                             
# ------------------------------------------------------------------------------------------------- 
#<record4xi record = "
#   npu2event4xi5test.txt
#   sense-npu2event4xi5test.xml
#   reason-npu2event4xi5test.xml
#   ace-npu2event4xi5test.xml
#"
#>

#<acknowledge4xi acknowledgement = "33" tester = "Small & Smart"/>

# -------------------------------------------------------------------------------------------------
# to-be-done                              
# -------------------------------------------------------------------------------------------------    
#<do4xi do = "
# nothing
#"
#/>

#<note4xi note = "
# parse4xi.py - to parse this module
# "/>

# -------------------------------------------------------------------------------------------------
# Legal Notice                             
# ------------------------------------------------------------------------------------------------- 
#<protect4xi protection = "copyright"
#   owner = "Small & Smart"
#   rights = "All rights reserved"
#   state = "California"
#   country = "United States of America"
#   codes = "Codes established in California and applicable to corporations in California"
#   compliance = "The California Law"
#   court = "Supreme Court of California, 350 McAllister Street, San Francisco, CA 94102-4783"
#/>
 

#<end4xi end = "
# -------------------------------------------------------------------------------------------------
# end of npu2device4xi.py                              
# ------------------------------------------------------------------------------------------------- 
#"
#/>
